@@ -1,15 +1,19 @@
 from types import ModuleType
 from importlib import import_module
 
-from .seed import seed_everything
-from .debug import is_debug_enabled, debug, set_debug
-
 import torch_geometric.data
 import torch_geometric.loader
 import torch_geometric.transforms
 import torch_geometric.utils
+import torch_geometric.explain
 import torch_geometric.profile
 
+from .seed import seed_everything
+from .home import get_home_dir, set_home_dir
+from .debug import is_debug_enabled, debug, set_debug
+from .experimental import (is_experimental_mode_enabled, experimental_mode,
+                           set_experimental_mode)
+
 
 # https://github.com/tensorflow/tensorflow/blob/master/tensorflow/
 # python/util/lazy_loader.py
@@ -17,7 +21,7 @@ class LazyLoader(ModuleType):
     def __init__(self, local_name, parent_module_globals, name):
         self._local_name = local_name
         self._parent_module_globals = parent_module_globals
-        super(LazyLoader, self).__init__(name)
+        super().__init__(name)
 
     def _load(self):
         module = import_module(self.__name__)
@@ -38,13 +42,18 @@ datasets = LazyLoader('datasets', globals(), 'torch_geometric.datasets')
 nn = LazyLoader('nn', globals(), 'torch_geometric.nn')
 graphgym = LazyLoader('graphgym', globals(), 'torch_geometric.graphgym')
 
-__version__ = '2.0.0'
+__version__ = '2.2.0'
 
 __all__ = [
     'seed_everything',
+    'get_home_dir',
+    'set_home_dir',
     'is_debug_enabled',
     'debug',
     'set_debug',
+    'is_experimental_mode_enabled',
+    'experimental_mode',
+    'set_experimental_mode',
     'torch_geometric',
     '__version__',
 ]
