@@ -1,19 +1,30 @@
-from typing import (Any, Optional, Iterable, Dict, List, Callable, Union,
-                    Tuple, NamedTuple)
-from torch_geometric.typing import NodeType, EdgeType
-
 import copy
-import weakref
 import warnings
+import weakref
 from collections import namedtuple
-from collections.abc import Sequence, Mapping, MutableMapping
+from collections.abc import Mapping, MutableMapping, Sequence
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    NamedTuple,
+    Optional,
+    Tuple,
+    Union,
+)
 
+import numpy as np
 import torch
 from torch import Tensor
 from torch_sparse import SparseTensor, coalesce
 
-from torch_geometric.utils import is_undirected
-from torch_geometric.data.view import KeysView, ValuesView, ItemsView
+from torch_geometric.data.view import ItemsView, KeysView, ValuesView
+from torch_geometric.typing import EdgeType, NodeType
+from torch_geometric.utils import contains_isolated_nodes, is_undirected
+
+N_KEYS = {'x', 'feat', 'pos', 'batch'}
 
 
 class BaseStorage(MutableMapping):
@@ -44,6 +55,9 @@ class BaseStorage(MutableMapping):
         return len(self._mapping)
 
     def __getattr__(self, key: str) -> Any:
+        if key == '_mapping':
+            self._mapping = {}
+            return self._mapping
         try:
             return self[key]
         except KeyError:
@@ -51,7 +65,10 @@ class BaseStorage(MutableMapping):
                 f"'{self.__class__.__name__}' object has no attribute '{key}'")
 
     def __setattr__(self, key: str, value: Any):
-        if key == '_parent':
+        propobj = getattr(self.__class__, key, None)
+        if propobj is not None and getattr(propobj, 'fset', None) is not None:
+            propobj.fset(self, value)
+        elif key == '_parent':
             self.__dict__[key] = weakref.ref(value)
         elif key[:1] == '_':
             self.__dict__[key] = value
@@ -68,8 +85,8 @@ class BaseStorage(MutableMapping):
         return self._mapping[key]
 
     def __setitem__(self, key: str, value: Any):
-        if value is None and key in self:
-            del self[key]
+        if value is None and key in self._mapping:
+            del self._mapping[key]
         elif value is not None:
             self._mapping[key] = value
 
@@ -95,7 +112,7 @@ class BaseStorage(MutableMapping):
         return out
 
     def __getstate__(self) -> Dict[str, Any]:
-        out = self.__dict__
+        out = self.__dict__.copy()
 
         _parent = out.get('_parent', None)
         if _parent is not None:
@@ -119,7 +136,7 @@ class BaseStorage(MutableMapping):
     # In contrast to standard `keys()`, `values()` and `items()` functions of
     # Python dictionaries, we allow to only iterate over a subset of items
     # denoted by a list of keys `args`.
-    # This is especically useful for adding PyTorch Tensor functionality to the
+    # This is especially useful for adding PyTorch Tensor functionality to the
     # storage object, e.g., in case we only want to transfer a subset of keys
     # to the GPU (i.e. the ones that are relevant to the deep learning model).
 
@@ -148,6 +165,9 @@ class BaseStorage(MutableMapping):
 
     # Additional functionality ################################################
 
+    def get(self, key: str, value: Optional[Any] = None) -> Any:
+        return self._mapping.get(key, value)
+
     def to_dict(self) -> Dict[str, Any]:
         r"""Returns a dictionary of stored key/value pairs."""
         return copy.copy(self._mapping)
@@ -229,17 +249,33 @@ class NodeStorage(BaseStorage):
             raise ValueError("'_key' does not denote a valid node type")
         return key
 
+    @property
+    def can_infer_num_nodes(self):
+        keys = set(self.keys())
+        num_node_keys = {
+            'num_nodes', 'x', 'pos', 'batch', 'adj', 'adj_t', 'edge_index',
+            'face'
+        }
+        if len(keys & num_node_keys) > 0:
+            return True
+        elif len([key for key in keys if 'node' in key]) > 0:
+            return True
+        else:
+            return False
+
     @property
     def num_nodes(self) -> Optional[int]:
         # We sequentially access attributes that reveal the number of nodes.
         if 'num_nodes' in self:
             return self['num_nodes']
-        for key, value in self.items('x', 'pos', 'batch'):
-            if isinstance(value, Tensor):
-                return value.size(self._parent().__cat_dim__(key, value, self))
+        for key, value in self.items():
+            if (isinstance(value, (Tensor, np.ndarray))
+                    and (key in N_KEYS or 'node' in key)):
+                cat_dim = self._parent().__cat_dim__(key, value, self)
+                return value.shape[cat_dim]
         if 'adj' in self and isinstance(self.adj, SparseTensor):
             return self.adj.size(0)
-        if 'adj_t' in self and isinstance(self.adj, SparseTensor):
+        if 'adj_t' in self and isinstance(self.adj_t, SparseTensor):
             return self.adj_t.size(1)
         warnings.warn(
             f"Unable to accurately infer 'num_nodes' from the attribute set "
@@ -261,7 +297,9 @@ class NodeStorage(BaseStorage):
 
     @property
     def num_node_features(self) -> int:
-        if 'x' in self and isinstance(self.x, Tensor):
+        if 'x' in self and isinstance(self.x, (Tensor, np.ndarray)):
+            return 1 if self.x.ndim == 1 else self.x.shape[-1]
+        if 'x' in self and isinstance(self.x, SparseTensor):
             return 1 if self.x.dim() == 1 else self.x.size(-1)
         return 0
 
@@ -269,6 +307,18 @@ class NodeStorage(BaseStorage):
     def num_features(self) -> int:
         return self.num_node_features
 
+    def is_node_attr(self, key: str) -> bool:
+        value = self[key]
+        cat_dim = self._parent().__cat_dim__(key, value, self)
+        if not isinstance(value, (Tensor, np.ndarray)):
+            return False
+        if value.ndim == 0 or value.shape[cat_dim] != self.num_nodes:
+            return False
+        return True
+
+    def is_edge_attr(self, key: str) -> bool:
+        return False
+
 
 class EdgeStorage(BaseStorage):
     r"""We support multiple ways to store edge connectivity in a
@@ -307,9 +357,10 @@ class EdgeStorage(BaseStorage):
     @property
     def num_edges(self) -> int:
         # We sequentially access attributes that reveal the number of edges.
-        for key, value in self.items('edge_index', 'edge_attr'):
-            if isinstance(value, Tensor):
-                return value.size(self._parent().__cat_dim__(key, value, self))
+        for key, value in self.items():
+            if isinstance(value, (Tensor, np.ndarray)) and 'edge' in key:
+                cat_dim = self._parent().__cat_dim__(key, value, self)
+                return value.shape[cat_dim]
         for value in self.values('adj', 'adj_t'):
             if isinstance(value, SparseTensor):
                 return value.nnz()
@@ -317,8 +368,9 @@ class EdgeStorage(BaseStorage):
 
     @property
     def num_edge_features(self) -> int:
-        if 'edge_attr' in self and isinstance(self.edge_attr, Tensor):
-            return 1 if self.edge_attr.dim() == 1 else self.edge_attr.size(-1)
+        if ('edge_attr' in self and isinstance(self.edge_attr,
+                                               (Tensor, np.ndarray))):
+            return 1 if self.edge_attr.ndim == 1 else self.edge_attr.shape[-1]
         return 0
 
     @property
@@ -338,6 +390,18 @@ class EdgeStorage(BaseStorage):
 
         return size if dim is None else size[dim]
 
+    def is_node_attr(self, key: str) -> bool:
+        return False
+
+    def is_edge_attr(self, key: str) -> bool:
+        value = self[key]
+        cat_dim = self._parent().__cat_dim__(key, value, self)
+        if not isinstance(value, (Tensor, np.ndarray)):
+            return False
+        if value.ndim == 0 or value.shape[cat_dim] != self.num_edges:
+            return False
+        return True
+
     def is_coalesced(self) -> bool:
         for value in self.values('adj', 'adj_t'):
             return value.is_coalesced()
@@ -364,7 +428,10 @@ class EdgeStorage(BaseStorage):
         edge_index, num_nodes = self.edge_index, self.size(1)
         if num_nodes is None:
             raise NameError("Unable to infer 'num_nodes'")
-        return torch.unique(edge_index[1]).numel() < num_nodes
+        if self.is_bipartite():
+            return torch.unique(edge_index[1]).numel() < num_nodes
+        else:
+            return contains_isolated_nodes(edge_index, num_nodes)
 
     def has_self_loops(self) -> bool:
         if self.is_bipartite():
@@ -373,7 +440,7 @@ class EdgeStorage(BaseStorage):
         return int((edge_index[0] == edge_index[1]).sum()) > 0
 
     def is_undirected(self) -> bool:
-        if self.is_bipartite():  # TODO check for inverse storage.
+        if self.is_bipartite():
             return False
 
         for value in self.values('adj', 'adj_t'):
@@ -405,6 +472,32 @@ class GlobalStorage(NodeStorage, EdgeStorage):
         size = (self.num_nodes, self.num_nodes)
         return size if dim is None else size[dim]
 
+    def is_node_attr(self, key: str) -> bool:
+        value = self[key]
+        cat_dim = self._parent().__cat_dim__(key, value, self)
+
+        num_nodes, num_edges = self.num_nodes, self.num_edges
+        if not isinstance(value, (Tensor, np.ndarray)):
+            return False
+        if value.ndim == 0 or value.shape[cat_dim] != num_nodes:
+            return False
+        if num_nodes != num_edges:
+            return True
+        return 'edge' not in key
+
+    def is_edge_attr(self, key: str) -> bool:
+        value = self[key]
+        cat_dim = self._parent().__cat_dim__(key, value, self)
+
+        num_nodes, num_edges = self.num_nodes, self.num_edges
+        if not isinstance(value, (Tensor, np.ndarray)):
+            return False
+        if value.ndim == 0 or value.shape[cat_dim] != num_edges:
+            return False
+        if num_nodes != num_edges:
+            return True
+        return 'edge' in key
+
 
 def recursive_apply_(data: Any, func: Callable):
     if isinstance(data, Tensor):
