@@ -1,12 +1,13 @@
-from typing import Optional, Callable, List
-
 import json
+import os
 import os.path as osp
+from typing import Callable, List, Optional
 
-import torch
 import numpy as np
 import scipy.sparse as sp
-from torch_geometric.data import InMemoryDataset, Data
+import torch
+
+from torch_geometric.data import Data, InMemoryDataset, download_url
 
 
 class AmazonProducts(InMemoryDataset):
@@ -24,7 +25,22 @@ class AmazonProducts(InMemoryDataset):
             an :obj:`torch_geometric.data.Data` object and returns a
             transformed version. The data object will be transformed before
             being saved to disk. (default: :obj:`None`)
+
+    Stats:
+        .. list-table::
+            :widths: 10 10 10 10
+            :header-rows: 1
+
+            * - #nodes
+              - #edges
+              - #features
+              - #classes
+            * - 1,569,960
+              - 264,339,468
+              - 200
+              - 107
     """
+    url = 'https://docs.google.com/uc?export=download&id={}&confirm=t'
 
     adj_full_id = '17qhNA8H1IpbkkR-T2BmPQm8QNW5do-aa'
     feats_id = '10SW8lCvAj-kb6ckkfTOC5y0l8XXdtMxj'
@@ -45,19 +61,17 @@ class AmazonProducts(InMemoryDataset):
         return 'data.pt'
 
     def download(self):
-        from google_drive_downloader import GoogleDriveDownloader as gdd
+        path = download_url(self.url.format(self.adj_full_id), self.raw_dir)
+        os.rename(path, osp.join(self.raw_dir, 'adj_full.npz'))
 
-        path = osp.join(self.raw_dir, 'adj_full.npz')
-        gdd.download_file_from_google_drive(self.adj_full_id, path)
+        path = download_url(self.url.format(self.feats_id), self.raw_dir)
+        os.rename(path, osp.join(self.raw_dir, 'feats.npy'))
 
-        path = osp.join(self.raw_dir, 'feats.npy')
-        gdd.download_file_from_google_drive(self.feats_id, path)
+        path = download_url(self.url.format(self.class_map_id), self.raw_dir)
+        os.rename(path, osp.join(self.raw_dir, 'class_map.json'))
 
-        path = osp.join(self.raw_dir, 'class_map.json')
-        gdd.download_file_from_google_drive(self.class_map_id, path)
-
-        path = osp.join(self.raw_dir, 'role.json')
-        gdd.download_file_from_google_drive(self.role_id, path)
+        path = download_url(self.url.format(self.role_id), self.raw_dir)
+        os.rename(path, osp.join(self.raw_dir, 'role.json'))
 
     def process(self):
         f = np.load(osp.join(self.raw_dir, 'adj_full.npz'))
