@@ -1,13 +1,17 @@
-from typing import Optional, Callable, List
-
 import os
 import os.path as osp
 import shutil
+from typing import Callable, List, Optional
 
 import torch
 from torch_sparse import coalesce, transpose
-from torch_geometric.data import (InMemoryDataset, HeteroData, download_url,
-                                  extract_zip)
+
+from torch_geometric.data import (
+    HeteroData,
+    InMemoryDataset,
+    download_url,
+    extract_zip,
+)
 
 
 class AMiner(InMemoryDataset):
