@@ -1,12 +1,15 @@
-from typing import Optional, Callable
-
-import os
 import datetime
+import os
+from typing import Callable, Optional
 
 import torch
 
-from torch_geometric.data import (InMemoryDataset, Data, download_url,
-                                  extract_gz)
+from torch_geometric.data import (
+    Data,
+    InMemoryDataset,
+    download_url,
+    extract_gz,
+)
 
 
 class BitcoinOTC(InMemoryDataset):
