@@ -1,14 +1,19 @@
-from typing import Optional, Callable, List
-
+import glob
 import os
 import os.path as osp
-import glob
 import pickle
+from typing import Callable, List, Optional
 
 import torch
 import torch.nn.functional as F
-from torch_geometric.data import (InMemoryDataset, Data, download_url,
-                                  extract_zip, extract_tar)
+
+from torch_geometric.data import (
+    Data,
+    InMemoryDataset,
+    download_url,
+    extract_tar,
+    extract_zip,
+)
 from torch_geometric.utils import to_undirected
 
 
@@ -53,6 +58,42 @@ class GEDDataset(InMemoryDataset):
             :obj:`torch_geometric.data.Data` object and returns a boolean
             value, indicating whether the data object should be included in the
             final dataset. (default: :obj:`None`)
+
+    Stats:
+        .. list-table::
+            :widths: 20 10 10 10 10 10
+            :header-rows: 1
+
+            * - Name
+              - #graphs
+              - #nodes
+              - #edges
+              - #features
+              - #classes
+            * - AIDS700nef
+              - 700
+              - ~8.9
+              - ~17.6
+              - 29
+              - 0
+            * - LINUX
+              - 1,000
+              - ~7.6
+              - ~13.9
+              - 0
+              - 0
+            * - ALKANE
+              - 150
+              - ~8.9
+              - ~15.8
+              - 0
+              - 0
+            * - IMDBMulti
+              - 1,500
+              - ~13.0
+              - ~131.9
+              - 0
+              - 0
     """
 
     url = 'https://drive.google.com/uc?export=download&id={}'
@@ -103,18 +144,22 @@ class GEDDataset(InMemoryDataset):
 
     @property
     def raw_file_names(self) -> List[str]:
+        # Returns, e.g., ['LINUX/train', 'LINUX/test']
         return [osp.join(self.name, s) for s in ['train', 'test']]
 
     @property
     def processed_file_names(self) -> List[str]:
+        # Returns, e.g., ['LINUX_training.pt', 'LINUX_test.pt']
         return [f'{self.name}_{s}.pt' for s in ['training', 'test']]
 
     def download(self):
+        # Downloads the .tar/.zip file of the graphs and extracts them:
         name = self.datasets[self.name]['id']
         path = download_url(self.url.format(name), self.raw_dir)
         self.datasets[self.name]['extract'](path, self.raw_dir)
         os.unlink(path)
 
+        # Downloads the pickle file containing pre-computed GEDs:
         name = self.datasets[self.name]['pickle']
         path = download_url(self.url.format(name), self.raw_dir)
         os.rename(path, osp.join(self.raw_dir, self.name, 'ged.pickle'))
@@ -123,16 +168,20 @@ class GEDDataset(InMemoryDataset):
         import networkx as nx
 
         ids, Ns = [], []
+        # Iterating over paths for raw and processed data (train + test):
         for r_path, p_path in zip(self.raw_paths, self.processed_paths):
+            # Find the paths of all raw graphs:
             names = glob.glob(osp.join(r_path, '*.gexf'))
-            # Get the graph IDs given by the file name:
+            # Get sorted graph IDs given filename: 123.gexf -> 123
             ids.append(sorted([int(i.split(os.sep)[-1][:-5]) for i in names]))
 
             data_list = []
             # Convert graphs in .gexf format to a NetworkX Graph:
             for i, idx in enumerate(ids[-1]):
                 i = i if len(ids) == 1 else i + len(ids[0])
+                # Reading the raw `*.gexf` graph:
                 G = nx.read_gexf(osp.join(r_path, f'{idx}.gexf'))
+                # Mapping of nodes in `G` to a contiguous number:
                 mapping = {name: j for j, name in enumerate(G.nodes())}
                 G = nx.relabel_nodes(G, mapping)
                 Ns.append(G.number_of_nodes())
@@ -146,7 +195,7 @@ class GEDDataset(InMemoryDataset):
                 data.num_nodes = Ns[-1]
 
                 # Create a one-hot encoded feature matrix denoting the atom
-                # type for the  AIDS700nef dataset:
+                # type (for the `AIDS700nef` dataset):
                 if self.name == 'AIDS700nef':
                     x = torch.zeros(data.num_nodes, dtype=torch.long)
                     for node, info in G.nodes(data=True):
@@ -167,7 +216,9 @@ class GEDDataset(InMemoryDataset):
         assoc = {idx: i for i, idx in enumerate(ids[0])}
         assoc.update({idx: i + len(ids[0]) for i, idx in enumerate(ids[1])})
 
+        # Extracting ground-truth GEDs from the GED pickle file
         path = osp.join(self.raw_dir, self.name, 'ged.pickle')
+        # Initialize GEDs as float('inf'):
         mat = torch.full((len(assoc), len(assoc)), float('inf'))
         with open(path, 'rb') as f:
             obj = pickle.load(f)
@@ -176,9 +227,11 @@ class GEDDataset(InMemoryDataset):
                 xs += [assoc[x]]
                 ys += [assoc[y]]
                 gs += [g]
+            # The pickle file does not contain GEDs for test graph pairs, i.e.
+            # GEDs for (test_graph, test_graph) pairs are still float('inf'):
             x, y = torch.tensor(xs), torch.tensor(ys)
-            g = torch.tensor(gs, dtype=torch.float)
-            mat[x, y], mat[y, x] = g, g
+            ged = torch.tensor(gs, dtype=torch.float)
+            mat[x, y], mat[y, x] = ged, ged
 
         path = osp.join(self.processed_dir, f'{self.name}_ged.pt')
         torch.save(mat, path)
