@@ -1,6 +1,8 @@
 import os.path as osp
+from typing import Callable, Optional
 
 import torch
+
 from torch_geometric.data import InMemoryDataset, TemporalData, download_url
 
 
@@ -8,27 +10,33 @@ class JODIEDataset(InMemoryDataset):
     url = 'http://snap.stanford.edu/jodie/{}.csv'
     names = ['reddit', 'wikipedia', 'mooc', 'lastfm']
 
-    def __init__(self, root, name, transform=None, pre_transform=None):
+    def __init__(
+        self,
+        root: str,
+        name: str,
+        transform: Optional[Callable] = None,
+        pre_transform: Optional[Callable] = None,
+    ):
         self.name = name.lower()
         assert self.name in self.names
 
-        super(JODIEDataset, self).__init__(root, transform, pre_transform)
+        super().__init__(root, transform, pre_transform)
         self.data, self.slices = torch.load(self.processed_paths[0])
 
     @property
-    def raw_dir(self):
+    def raw_dir(self) -> str:
         return osp.join(self.root, self.name, 'raw')
 
     @property
-    def processed_dir(self):
+    def processed_dir(self) -> str:
         return osp.join(self.root, self.name, 'processed')
 
     @property
-    def raw_file_names(self):
+    def raw_file_names(self) -> str:
         return f'{self.name}.csv'
 
     @property
-    def processed_file_names(self):
+    def processed_file_names(self) -> str:
         return 'data.pt'
 
     def download(self):
@@ -53,5 +61,5 @@ class JODIEDataset(InMemoryDataset):
 
         torch.save(self.collate([data]), self.processed_paths[0])
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f'{self.name.capitalize()}()'
