@@ -1,69 +1,16 @@
 import os
 import os.path as osp
 import re
+from typing import Callable, Optional
 
 import torch
-from torch_geometric.data import (InMemoryDataset, Data, download_url,
-                                  extract_gz)
 
-try:
-    from rdkit import Chem
-except ImportError:
-    Chem = None
-
-x_map = {
-    'atomic_num':
-    list(range(0, 119)),
-    'chirality': [
-        'CHI_UNSPECIFIED',
-        'CHI_TETRAHEDRAL_CW',
-        'CHI_TETRAHEDRAL_CCW',
-        'CHI_OTHER',
-    ],
-    'degree':
-    list(range(0, 11)),
-    'formal_charge':
-    list(range(-5, 7)),
-    'num_hs':
-    list(range(0, 9)),
-    'num_radical_electrons':
-    list(range(0, 5)),
-    'hybridization': [
-        'UNSPECIFIED',
-        'S',
-        'SP',
-        'SP2',
-        'SP3',
-        'SP3D',
-        'SP3D2',
-        'OTHER',
-    ],
-    'is_aromatic': [False, True],
-    'is_in_ring': [False, True],
-}
-
-e_map = {
-    'bond_type': [
-        'misc',
-        'SINGLE',
-        'DOUBLE',
-        'TRIPLE',
-        'AROMATIC',
-    ],
-    'stereo': [
-        'STEREONONE',
-        'STEREOZ',
-        'STEREOE',
-        'STEREOCIS',
-        'STEREOTRANS',
-        'STEREOANY',
-    ],
-    'is_conjugated': [False, True],
-}
+from torch_geometric.data import InMemoryDataset, download_url, extract_gz
+from torch_geometric.utils import from_smiles
 
 
 class MoleculeNet(InMemoryDataset):
-    r"""The `MoleculeNet <http://moleculenet.ai/datasets-1>`_ benchmark
+    r"""The `MoleculeNet <http://moleculenet.org/datasets-1>`_ benchmark
     collection  from the `"MoleculeNet: A Benchmark for Molecular Machine
     Learning" <https://arxiv.org/abs/1703.00564>`_ paper, containing datasets
     from physical chemistry, biophysics and physiology.
@@ -88,6 +35,90 @@ class MoleculeNet(InMemoryDataset):
             :obj:`torch_geometric.data.Data` object and returns a boolean
             value, indicating whether the data object should be included in the
             final dataset. (default: :obj:`None`)
+
+    Stats:
+        .. list-table::
+            :widths: 20 10 10 10 10 10
+            :header-rows: 1
+
+            * - Name
+              - #graphs
+              - #nodes
+              - #edges
+              - #features
+              - #classes
+            * - ESOL
+              - 1,128
+              - ~13.3
+              - ~27.4
+              - 9
+              - 1
+            * - FreeSolv
+              - 642
+              - ~8.7
+              - ~16.8
+              - 9
+              - 1
+            * - Lipophilicity
+              - 4,200
+              - ~27.0
+              - ~59.0
+              - 9
+              - 1
+            * - PCBA
+              - 437,929
+              - ~26.0
+              - ~56.2
+              - 9
+              - 128
+            * - MUV
+              - 93,087
+              - ~24.2
+              - ~52.6
+              - 9
+              - 17
+            * - HIV
+              - 41,127
+              - ~25.5
+              - ~54.9
+              - 9
+              - 1
+            * - BACE
+              - 1513
+              - ~34.1
+              - ~73.7
+              - 9
+              - 1
+            * - BBPB
+              - 2,050
+              - ~23.9
+              - ~51.6
+              - 9
+              - 1
+            * - Tox21
+              - 7,831
+              - ~18.6
+              - ~38.6
+              - 9
+              - 12
+            * - ToxCast
+              - 8,597
+              - ~18.7
+              - ~38.4
+              - 9
+              - 617
+            * - SIDER
+              - 1,427
+              - ~33.6
+              - ~70.7
+              - 9
+              - 27
+            * - ClinTox
+              - 1,484
+              - ~26.1
+              - ~55.5
+              - 9
+              - 2
     """
 
     url = 'https://deepchemdata.s3-us-west-1.amazonaws.com/datasets/{}'
@@ -115,32 +146,33 @@ class MoleculeNet(InMemoryDataset):
                     slice(1, 3)],
     }
 
-    def __init__(self, root, name, transform=None, pre_transform=None,
-                 pre_filter=None):
-
-        if Chem is None:
-            raise ImportError('`MoleculeNet` requires `rdkit`.')
-
+    def __init__(
+        self,
+        root: str,
+        name: str,
+        transform: Optional[Callable] = None,
+        pre_transform: Optional[Callable] = None,
+        pre_filter: Optional[Callable] = None,
+    ):
         self.name = name.lower()
         assert self.name in self.names.keys()
-        super(MoleculeNet, self).__init__(root, transform, pre_transform,
-                                          pre_filter)
+        super().__init__(root, transform, pre_transform, pre_filter)
         self.data, self.slices = torch.load(self.processed_paths[0])
 
     @property
-    def raw_dir(self):
+    def raw_dir(self) -> str:
         return osp.join(self.root, self.name, 'raw')
 
     @property
-    def processed_dir(self):
+    def processed_dir(self) -> str:
         return osp.join(self.root, self.name, 'processed')
 
     @property
-    def raw_file_names(self):
+    def raw_file_names(self) -> str:
         return f'{self.names[self.name][2]}.csv'
 
     @property
-    def processed_file_names(self):
+    def processed_file_names(self) -> str:
         return 'data.pt'
 
     def download(self):
@@ -167,52 +199,8 @@ class MoleculeNet(InMemoryDataset):
             ys = [float(y) if len(y) > 0 else float('NaN') for y in ys]
             y = torch.tensor(ys, dtype=torch.float).view(1, -1)
 
-            mol = Chem.MolFromSmiles(smiles)
-            if mol is None:
-                continue
-
-            xs = []
-            for atom in mol.GetAtoms():
-                x = []
-                x.append(x_map['atomic_num'].index(atom.GetAtomicNum()))
-                x.append(x_map['chirality'].index(str(atom.GetChiralTag())))
-                x.append(x_map['degree'].index(atom.GetTotalDegree()))
-                x.append(x_map['formal_charge'].index(atom.GetFormalCharge()))
-                x.append(x_map['num_hs'].index(atom.GetTotalNumHs()))
-                x.append(x_map['num_radical_electrons'].index(
-                    atom.GetNumRadicalElectrons()))
-                x.append(x_map['hybridization'].index(
-                    str(atom.GetHybridization())))
-                x.append(x_map['is_aromatic'].index(atom.GetIsAromatic()))
-                x.append(x_map['is_in_ring'].index(atom.IsInRing()))
-                xs.append(x)
-
-            x = torch.tensor(xs, dtype=torch.long).view(-1, 9)
-
-            edge_indices, edge_attrs = [], []
-            for bond in mol.GetBonds():
-                i = bond.GetBeginAtomIdx()
-                j = bond.GetEndAtomIdx()
-
-                e = []
-                e.append(e_map['bond_type'].index(str(bond.GetBondType())))
-                e.append(e_map['stereo'].index(str(bond.GetStereo())))
-                e.append(e_map['is_conjugated'].index(bond.GetIsConjugated()))
-
-                edge_indices += [[i, j], [j, i]]
-                edge_attrs += [e, e]
-
-            edge_index = torch.tensor(edge_indices)
-            edge_index = edge_index.t().to(torch.long).view(2, -1)
-            edge_attr = torch.tensor(edge_attrs, dtype=torch.long).view(-1, 3)
-
-            # Sort indices.
-            if edge_index.numel() > 0:
-                perm = (edge_index[0] * x.size(0) + edge_index[1]).argsort()
-                edge_index, edge_attr = edge_index[:, perm], edge_attr[perm]
-
-            data = Data(x=x, edge_index=edge_index, edge_attr=edge_attr, y=y,
-                        smiles=smiles)
+            data = from_smiles(smiles)
+            data.y = y
 
             if self.pre_filter is not None and not self.pre_filter(data):
                 continue
@@ -224,5 +212,5 @@ class MoleculeNet(InMemoryDataset):
 
         torch.save(self.collate(data_list), self.processed_paths[0])
 
-    def __repr__(self):
-        return '{}({})'.format(self.names[self.name][0], len(self))
+    def __repr__(self) -> str:
+        return f'{self.names[self.name][0]}({len(self)})'
