@@ -1,9 +1,10 @@
-import os.path as osp
 import glob
+import os.path as osp
 
-import torch
 import numpy as np
+import torch
 from torch_scatter import scatter_add
+
 from torch_geometric.data import Data, Dataset
 
 
@@ -31,7 +32,7 @@ class TrackMLParticleTrackingDataset(Dataset):
     url = 'https://www.kaggle.com/c/trackml-particle-identification'
 
     def __init__(self, root, transform=None):
-        super(TrackMLParticleTrackingDataset, self).__init__(root, transform)
+        super().__init__(root, transform)
         events = glob.glob(osp.join(self.raw_dir, 'event*-hits.csv'))
         events = [e.split(osp.sep)[-1].split('-')[0][5:] for e in events]
         self.events = sorted(events)
@@ -48,8 +49,8 @@ class TrackMLParticleTrackingDataset(Dataset):
 
     def download(self):
         raise RuntimeError(
-            'Dataset not found. Please download it from {} and move all '
-            '*.csv files to {}'.format(self.url, self.raw_dir))
+            f'Dataset not found. Please download it from {self.url} and move '
+            f'all *.csv files to {self.raw_dir}')
 
     def len(self):
         return len(glob.glob(osp.join(self.raw_dir, 'event*-hits.csv')))
