@@ -1,12 +1,17 @@
+import glob
 import os
 import os.path as osp
 import shutil
-import glob
+from typing import Callable, List, Optional
 
 import torch
-from scipy.io import loadmat
-from torch_geometric.data import (Data, InMemoryDataset, download_url,
-                                  extract_zip)
+
+from torch_geometric.data import (
+    Data,
+    InMemoryDataset,
+    download_url,
+    extract_zip,
+)
 
 
 class PascalPF(InMemoryDataset):
@@ -45,26 +50,27 @@ class PascalPF(InMemoryDataset):
         'pottedplant', 'sheep', 'sofa', 'train', 'tvmonitor'
     ]
 
-    def __init__(self, root, category, transform=None, pre_transform=None,
-                 pre_filter=None):
+    def __init__(
+        self,
+        root: str,
+        category: str,
+        transform: Optional[Callable] = None,
+        pre_transform: Optional[Callable] = None,
+        pre_filter: Optional[Callable] = None,
+    ):
         self.category = category.lower()
         assert self.category in self.categories
-        super(PascalPF, self).__init__(root, transform, pre_transform,
-                                       pre_filter)
-
+        super().__init__(root, transform, pre_transform, pre_filter)
         self.data, self.slices = torch.load(self.processed_paths[0])
         self.pairs = torch.load(self.processed_paths[1])
 
     @property
-    def raw_file_names(self):
+    def raw_file_names(self) -> List[str]:
         return ['Annotations', 'parsePascalVOC.mat']
 
     @property
-    def processed_file_names(self):
-        return [
-            '{}.pt'.format(self.category),
-            '{}_pairs.pt'.format(self.category),
-        ]
+    def processed_file_names(self) -> List[str]:
+        return [f'{self.category}.pt', f'{self.category}_pairs.pt']
 
     def download(self):
         path = download_url(self.url, self.root)
@@ -73,6 +79,8 @@ class PascalPF(InMemoryDataset):
         os.rename(osp.join(self.root, 'PF-dataset-PASCAL'), self.raw_dir)
 
     def process(self):
+        from scipy.io import loadmat
+
         path = osp.join(self.raw_dir, 'Annotations', self.category, '*.mat')
         filenames = glob.glob(path)
 
@@ -110,6 +118,6 @@ class PascalPF(InMemoryDataset):
         torch.save(self.collate(data_list), self.processed_paths[0])
         torch.save(pairs, self.processed_paths[1])
 
-    def __repr__(self):
-        return '{}({}, category={})'.format(self.__class__.__name__, len(self),
-                                            self.category)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({len(self)}, '
+                f'category={self.category})')
