@@ -1,12 +1,17 @@
+import json
 import os
 import os.path as osp
 import shutil
-import json
+from typing import Callable, List, Optional, Union
 
 import torch
 
-from torch_geometric.data import (Data, InMemoryDataset, download_url,
-                                  extract_zip)
+from torch_geometric.data import (
+    Data,
+    InMemoryDataset,
+    download_url,
+    extract_zip,
+)
 from torch_geometric.io import read_txt_array
 
 
@@ -29,7 +34,9 @@ class ShapeNet(InMemoryDataset):
             Can be explicitly set to :obj:`None` to load all categories.
             (default: :obj:`None`)
         include_normals (bool, optional): If set to :obj:`False`, will not
-            include normal vectors as input features. (default: :obj:`True`)
+            include normal vectors as input features to :obj:`data.x`.
+            As a result, :obj:`data.x` will be :obj:`None`.
+            (default: :obj:`True`)
         split (string, optional): If :obj:`"train"`, loads the training
             dataset.
             If :obj:`"val"`, loads the validation dataset.
@@ -48,6 +55,22 @@ class ShapeNet(InMemoryDataset):
             :obj:`torch_geometric.data.Data` object and returns a boolean
             value, indicating whether the data object should be included in the
             final dataset. (default: :obj:`None`)
+
+    Stats:
+        .. list-table::
+            :widths: 10 10 10 10 10
+            :header-rows: 1
+
+            * - #graphs
+              - #nodes
+              - #edges
+              - #features
+              - #classes
+            * - 16,881
+              - ~2,616.2
+              - 0
+              - 3
+              - 50
     """
 
     url = ('https://shapenet.cs.stanford.edu/media/'
@@ -91,17 +114,23 @@ class ShapeNet(InMemoryDataset):
         'Table': [47, 48, 49],
     }
 
-    def __init__(self, root, categories=None, include_normals=True,
-                 split='trainval', transform=None, pre_transform=None,
-                 pre_filter=None):
+    def __init__(
+        self,
+        root: str,
+        categories: Optional[Union[str, List[str]]] = None,
+        include_normals: bool = True,
+        split: str = 'trainval',
+        transform: Optional[Callable] = None,
+        pre_transform: Optional[Callable] = None,
+        pre_filter: Optional[Callable] = None,
+    ):
         if categories is None:
             categories = list(self.category_ids.keys())
         if isinstance(categories, str):
             categories = [categories]
         assert all(category in self.category_ids for category in categories)
         self.categories = categories
-        super(ShapeNet, self).__init__(root, transform, pre_transform,
-                                       pre_filter)
+        super().__init__(root, transform, pre_transform, pre_filter)
 
         if split == 'train':
             path = self.processed_paths[0]
@@ -124,18 +153,18 @@ class ShapeNet(InMemoryDataset):
             self.y_mask[i, labels] = 1
 
     @property
-    def num_classes(self):
+    def num_classes(self) -> int:
         return self.y_mask.size(-1)
 
     @property
-    def raw_file_names(self):
+    def raw_file_names(self) -> List[str]:
         return list(self.category_ids.values()) + ['train_test_split']
 
     @property
-    def processed_file_names(self):
+    def processed_file_names(self) -> str:
         cats = '_'.join([cat[:3].lower() for cat in self.categories])
         return [
-            os.path.join('{}_{}.pt'.format(cats, split))
+            osp.join(f'{cats}_{split}.pt')
             for split in ['train', 'val', 'test', 'trainval']
         ]
 
@@ -147,7 +176,7 @@ class ShapeNet(InMemoryDataset):
         name = self.url.split('/')[-1].split('.')[0]
         os.rename(osp.join(self.root, name), self.raw_dir)
 
-    def process_filenames(self, filenames):
+    def process_filenames(self, filenames: List[str]) -> List[Data]:
         data_list = []
         categories_ids = [self.category_ids[cat] for cat in self.categories]
         cat_idx = {categories_ids[i]: i for i in range(len(categories_ids))}
@@ -186,6 +215,6 @@ class ShapeNet(InMemoryDataset):
             torch.save(self.collate(data_list), self.processed_paths[i])
         torch.save(self.collate(trainval), self.processed_paths[3])
 
-    def __repr__(self):
-        return '{}({}, categories={})'.format(self.__class__.__name__,
-                                              len(self), self.categories)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({len(self)}, '
+                f'categories={self.categories})')
