@@ -1,26 +1,33 @@
 import os
 import os.path as osp
+from typing import Any, Callable, List, Optional
 
-import torch
-import pandas
 import numpy as np
+import torch
 from torch_sparse import coalesce
-from torch_geometric.data import (Data, InMemoryDataset, download_url,
-                                  extract_gz, extract_tar)
+
+from torch_geometric.data import (
+    Data,
+    InMemoryDataset,
+    download_url,
+    extract_gz,
+    extract_tar,
+)
 from torch_geometric.data.makedirs import makedirs
 
 
 class EgoData(Data):
-    def __inc__(self, key, item):
+    def __inc__(self, key: str, value: Any, *args, **kwargs):
         if key == 'circle':
             return self.num_nodes
         elif key == 'circle_batch':
-            return item.max().item() + 1 if item.numel() > 0 else 0
-        else:
-            return super(EgoData, self).__inc__(key, item)
+            return int(value.max()) + 1 if value.numel() > 0 else 0
+        return super().__inc__(key, value, *args, **kwargs)
 
 
-def read_ego(files, name):
+def read_ego(files: List[str], name: str) -> List[EgoData]:
+    import pandas as pd
+
     all_featnames = []
     files = [
         x for x in files if x.split('.')[-1] in
@@ -45,12 +52,11 @@ def read_ego(files, name):
 
         x = None
         if name != 'gplus':  # Don't read node features on g-plus:
-            x_ego = pandas.read_csv(egofeat_file, sep=' ', header=None,
-                                    dtype=np.float32)
+            x_ego = pd.read_csv(egofeat_file, sep=' ', header=None,
+                                dtype=np.float32)
             x_ego = torch.from_numpy(x_ego.values)
 
-            x = pandas.read_csv(feat_file, sep=' ', header=None,
-                                dtype=np.float32)
+            x = pd.read_csv(feat_file, sep=' ', header=None, dtype=np.float32)
             x = torch.from_numpy(x.values)[:, 1:]
 
             x_all = torch.cat([x, x_ego], dim=0)
@@ -64,8 +70,8 @@ def read_ego(files, name):
             x_all[:, torch.tensor(indices)] = x
             x = x_all
 
-        idx = pandas.read_csv(feat_file, sep=' ', header=None, dtype=str,
-                              usecols=[0], squeeze=True)
+        idx = pd.read_csv(feat_file, sep=' ', header=None, dtype=str,
+                          usecols=[0]).squeeze()
 
         idx_assoc = {}
         for i, j in enumerate(idx):
@@ -82,10 +88,10 @@ def read_ego(files, name):
         circle_batch = torch.tensor(circles_batch)
 
         try:
-            row = pandas.read_csv(edges_file, sep=' ', header=None, dtype=str,
-                                  usecols=[0], squeeze=True)
-            col = pandas.read_csv(edges_file, sep=' ', header=None, dtype=str,
-                                  usecols=[1], squeeze=True)
+            row = pd.read_csv(edges_file, sep=' ', header=None, dtype=str,
+                              usecols=[0]).squeeze()
+            col = pd.read_csv(edges_file, sep=' ', header=None, dtype=str,
+                              usecols=[1]).squeeze()
         except:  # noqa
             continue
 
@@ -104,21 +110,23 @@ def read_ego(files, name):
         edge_index = torch.stack([row, col], dim=0)
 
         edge_index, _ = coalesce(edge_index, None, N, N)
-        data = Data(x=x, edge_index=edge_index, circle=circle,
-                    circle_batch=circle_batch)
+        data = EgoData(x=x, edge_index=edge_index, circle=circle,
+                       circle_batch=circle_batch)
 
         data_list.append(data)
 
     return data_list
 
 
-def read_soc(files, name):
+def read_soc(files: List[str], name: str) -> List[Data]:
+    import pandas as pd
+
     skiprows = 4
     if name == 'pokec':
         skiprows = 0
 
-    edge_index = pandas.read_csv(files[0], sep='\t', header=None,
-                                 skiprows=skiprows, dtype=np.int64)
+    edge_index = pd.read_csv(files[0], sep='\t', header=None,
+                             skiprows=skiprows, dtype=np.int64)
     edge_index = torch.from_numpy(edge_index.values).t()
     num_nodes = edge_index.max().item() + 1
     edge_index, _ = coalesce(edge_index, None, num_nodes, num_nodes)
@@ -126,9 +134,11 @@ def read_soc(files, name):
     return [Data(edge_index=edge_index, num_nodes=num_nodes)]
 
 
-def read_wiki(files, name):
-    edge_index = pandas.read_csv(files[0], sep='\t', header=None, skiprows=4,
-                                 dtype=np.int64)
+def read_wiki(files: List[str], name: str) -> List[Data]:
+    import pandas as pd
+
+    edge_index = pd.read_csv(files[0], sep='\t', header=None, skiprows=4,
+                             dtype=np.int64)
     edge_index = torch.from_numpy(edge_index.values).t()
 
     idx = torch.unique(edge_index.flatten())
@@ -179,24 +189,29 @@ class SNAPDataset(InMemoryDataset):
         'wiki-vote': ['wiki-Vote.txt.gz'],
     }
 
-    def __init__(self, root, name, transform=None, pre_transform=None,
-                 pre_filter=None):
+    def __init__(
+        self,
+        root: str,
+        name: str,
+        transform: Optional[Callable] = None,
+        pre_transform: Optional[Callable] = None,
+        pre_filter: Optional[Callable] = None,
+    ):
         self.name = name.lower()
         assert self.name in self.available_datasets.keys()
-        super(SNAPDataset, self).__init__(root, transform, pre_transform,
-                                          pre_filter)
+        super().__init__(root, transform, pre_transform, pre_filter)
         self.data, self.slices = torch.load(self.processed_paths[0])
 
     @property
-    def raw_dir(self):
+    def raw_dir(self) -> str:
         return osp.join(self.root, self.name, 'raw')
 
     @property
-    def processed_dir(self):
+    def processed_dir(self) -> str:
         return osp.join(self.root, self.name, 'processed')
 
     @property
-    def processed_file_names(self):
+    def processed_file_names(self) -> str:
         return 'data.pt'
 
     def _download(self):
@@ -208,8 +223,7 @@ class SNAPDataset(InMemoryDataset):
 
     def download(self):
         for name in self.available_datasets[self.name]:
-            path = download_url('{}/{}'.format(self.url, name), self.raw_dir)
-            print(path)
+            path = download_url(f'{self.url}/{name}', self.raw_dir)
             if name.endswith('.tar.gz'):
                 extract_tar(path, self.raw_dir)
             elif name.endswith('.gz'):
@@ -241,5 +255,5 @@ class SNAPDataset(InMemoryDataset):
 
         torch.save(self.collate(data_list), self.processed_paths[0])
 
-    def __repr__(self):
-        return 'SNAP-{}({})'.format(self.name, len(self))
+    def __repr__(self) -> str:
+        return f'SNAP-{self.name}({len(self)})'
