@@ -1,17 +1,27 @@
-from typing import Optional, Union, Tuple
-from torch_geometric.typing import OptTensor, Adj
+from typing import Optional, Tuple, Union
 
 import torch
-from torch import Tensor
 import torch.nn.functional as F
-from torch.nn import Parameter as Param
+from torch import Tensor
 from torch.nn import Parameter
+from torch.nn import Parameter as Param
 from torch_scatter import scatter
-from torch_sparse import SparseTensor, matmul, masked_select_nnz
+from torch_sparse import SparseTensor, masked_select_nnz, matmul
+
 from torch_geometric.nn.conv import MessagePassing
+from torch_geometric.typing import Adj, OptTensor
 
 from ..inits import glorot, zeros
 
+try:
+    from pyg_lib.ops import segment_matmul  # noqa
+    _WITH_PYG_LIB = True
+except ImportError:
+    _WITH_PYG_LIB = False
+
+    def segment_matmul(inputs: Tensor, ptr: Tensor, other: Tensor) -> Tensor:
+        raise NotImplementedError
+
 
 @torch.jit._overload
 def masked_edge_index(edge_index, edge_mask):
@@ -65,12 +75,11 @@ class RGCNConv(MessagePassing):
             correspond to the number of nodes in your graph.
         out_channels (int): Size of each output sample.
         num_relations (int): Number of relations.
-        num_bases (int, optional): If set to not :obj:`None`, this layer will
-            use the basis-decomposition regularization scheme where
-            :obj:`num_bases` denotes the number of bases to use.
-            (default: :obj:`None`)
-        num_blocks (int, optional): If set to not :obj:`None`, this layer will
-            use the block-diagonal-decomposition regularization scheme where
+        num_bases (int, optional): If set, this layer will use the
+            basis-decomposition regularization scheme where :obj:`num_bases`
+            denotes the number of bases to use. (default: :obj:`None`)
+        num_blocks (int, optional): If set, this layer will use the
+            block-diagonal-decomposition regularization scheme where
             :obj:`num_blocks` denotes the number of blocks to use.
             (default: :obj:`None`)
         aggr (string, optional): The aggregation scheme to use
@@ -79,21 +88,31 @@ class RGCNConv(MessagePassing):
         root_weight (bool, optional): If set to :obj:`False`, the layer will
             not add transformed root node features to the output.
             (default: :obj:`True`)
+        is_sorted (bool, optional): If set to :obj:`True`, assumes that
+            :obj:`edge_index` is sorted by :obj:`edge_type`. This avoids
+            internal re-sorting of the data and can improve runtime and memory
+            efficiency. (default: :obj:`False`)
         bias (bool, optional): If set to :obj:`False`, the layer will not learn
             an additive bias. (default: :obj:`True`)
         **kwargs (optional): Additional arguments of
             :class:`torch_geometric.nn.conv.MessagePassing`.
     """
-    def __init__(self, in_channels: Union[int, Tuple[int, int]],
-                 out_channels: int,
-                 num_relations: int,
-                 num_bases: Optional[int] = None,
-                 num_blocks: Optional[int] = None,
-                 aggr: str = 'mean',
-                 root_weight: bool = True,
-                 bias: bool = True, **kwargs):  # yapf: disable
-
-        super(RGCNConv, self).__init__(aggr=aggr, node_dim=0, **kwargs)
+    def __init__(
+        self,
+        in_channels: Union[int, Tuple[int, int]],
+        out_channels: int,
+        num_relations: int,
+        num_bases: Optional[int] = None,
+        num_blocks: Optional[int] = None,
+        aggr: str = 'mean',
+        root_weight: bool = True,
+        is_sorted: bool = False,
+        bias: bool = True,
+        **kwargs,
+    ):
+        kwargs.setdefault('aggr', aggr)
+        super().__init__(node_dim=0, **kwargs)
+        self._WITH_PYG_LIB = _WITH_PYG_LIB
 
         if num_bases is not None and num_blocks is not None:
             raise ValueError('Can not apply both basis-decomposition and '
@@ -104,6 +123,7 @@ class RGCNConv(MessagePassing):
         self.num_relations = num_relations
         self.num_bases = num_bases
         self.num_blocks = num_blocks
+        self.is_sorted = is_sorted
 
         if isinstance(in_channels, int):
             in_channels = (in_channels, in_channels)
@@ -156,6 +176,7 @@ class RGCNConv(MessagePassing):
                 are treated as trainable node embeddings).
                 Furthermore, :obj:`x` can be of type :obj:`tuple` denoting
                 source and destination node features.
+            edge_index (LongTensor or SparseTensor): The edge indices.
             edge_type: The one-dimensional relation type/index for each edge in
                 :obj:`edge_index`.
                 Should be only :obj:`None` in case :obj:`edge_index` is of type
@@ -182,7 +203,7 @@ class RGCNConv(MessagePassing):
             edge_type = edge_index.storage.value()
         assert edge_type is not None
 
-        # propagate_type: (x: Tensor)
+        # propagate_type: (x: Tensor, edge_type_ptr: OptTensor)
         out = torch.zeros(x_r.size(0), self.out_channels, device=x_r.device)
 
         weight = self.weight
@@ -198,42 +219,62 @@ class RGCNConv(MessagePassing):
 
             for i in range(self.num_relations):
                 tmp = masked_edge_index(edge_index, edge_type == i)
-                h = self.propagate(tmp, x=x_l, size=size)
+                h = self.propagate(tmp, x=x_l, edge_type_ptr=None, size=size)
                 h = h.view(-1, weight.size(1), weight.size(2))
                 h = torch.einsum('abc,bcd->abd', h, weight[i])
-                out += h.contiguous().view(-1, self.out_channels)
+                out = out + h.contiguous().view(-1, self.out_channels)
 
         else:  # No regularization/Basis-decomposition ========================
-            for i in range(self.num_relations):
-                tmp = masked_edge_index(edge_index, edge_type == i)
+            if (self._WITH_PYG_LIB and self.num_bases is None
+                    and x_l.is_floating_point()
+                    and isinstance(edge_index, Tensor)):
+                if not self.is_sorted:
+                    if (edge_type[1:] < edge_type[:-1]).any():
+                        edge_type, perm = edge_type.sort()
+                        edge_index = edge_index[:, perm]
+                edge_type_ptr = torch.ops.torch_sparse.ind2ptr(
+                    edge_type, self.num_relations)
+                out = self.propagate(edge_index, x=x_l,
+                                     edge_type_ptr=edge_type_ptr, size=size)
+            else:
+                for i in range(self.num_relations):
+                    tmp = masked_edge_index(edge_index, edge_type == i)
 
-                if x_l.dtype == torch.long:
-                    out += self.propagate(tmp, x=weight[i, x_l], size=size)
-                else:
-                    h = self.propagate(tmp, x=x_l, size=size)
-                    out = out + (h @ weight[i])
+                    if x_l.dtype == torch.long:
+                        out = out + self.propagate(
+                            tmp,
+                            x=weight[i, x_l],
+                            edge_type_ptr=None,
+                            size=size,
+                        )
+                    else:
+                        h = self.propagate(tmp, x=x_l, edge_type_ptr=None,
+                                           size=size)
+                        out = out + (h @ weight[i])
 
         root = self.root
         if root is not None:
-            out += root[x_r] if x_r.dtype == torch.long else x_r @ root
+            out = out + (root[x_r] if x_r.dtype == torch.long else x_r @ root)
 
         if self.bias is not None:
-            out += self.bias
+            out = out + self.bias
 
         return out
 
-    def message(self, x_j: Tensor) -> Tensor:
+    def message(self, x_j: Tensor, edge_type_ptr: OptTensor) -> Tensor:
+        if edge_type_ptr is not None:
+            # TODO Re-weight according to edge type degree for `aggr=mean`.
+            return segment_matmul(x_j, edge_type_ptr, self.weight)
+
         return x_j
 
     def message_and_aggregate(self, adj_t: SparseTensor, x: Tensor) -> Tensor:
-        adj_t = adj_t.set_value(None, layout=None)
+        adj_t = adj_t.set_value(None)
         return matmul(adj_t, x, reduce=self.aggr)
 
-    def __repr__(self):
-        return '{}({}, {}, num_relations={})'.format(self.__class__.__name__,
-                                                     self.in_channels,
-                                                     self.out_channels,
-                                                     self.num_relations)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({self.in_channels}, '
+                f'{self.out_channels}, num_relations={self.num_relations})')
 
 
 class FastRGCNConv(RGCNConv):
@@ -264,14 +305,15 @@ class FastRGCNConv(RGCNConv):
 
         root = self.root
         if root is not None:
-            out += root[x_r] if x_r.dtype == torch.long else x_r @ root
+            out = out + (root[x_r] if x_r.dtype == torch.long else x_r @ root)
 
         if self.bias is not None:
-            out += self.bias
+            out = out + self.bias
 
         return out
 
-    def message(self, x_j: Tensor, edge_type: Tensor, index: Tensor) -> Tensor:
+    def message(self, x_j: Tensor, edge_type: Tensor,
+                edge_index_j: Tensor) -> Tensor:
         weight = self.weight
         if self.num_bases is not None:  # Basis-decomposition =================
             weight = (self.comp @ weight.view(self.num_bases, -1)).view(
@@ -288,7 +330,7 @@ class FastRGCNConv(RGCNConv):
 
         else:  # No regularization/Basis-decomposition ========================
             if x_j.dtype == torch.long:
-                weight_index = edge_type * weight.size(1) + index
+                weight_index = edge_type * weight.size(1) + edge_index_j
                 return weight.view(-1, self.out_channels)[weight_index]
 
             return torch.bmm(x_j.unsqueeze(-2), weight[edge_type]).squeeze(-2)
