@@ -1,12 +1,14 @@
 import math
-from typing import Union, Tuple, Optional
-from torch_geometric.typing import PairTensor, Adj, OptTensor
+from typing import Optional, Tuple, Union
 
 import torch
-from torch import Tensor
 import torch.nn.functional as F
-from torch.nn import Linear
+from torch import Tensor
+from torch_sparse import SparseTensor
+
 from torch_geometric.nn.conv import MessagePassing
+from torch_geometric.nn.dense.linear import Linear
+from torch_geometric.typing import Adj, OptTensor, PairTensor
 from torch_geometric.utils import softmax
 
 
@@ -28,8 +30,10 @@ class TransformerConv(MessagePassing):
         {\sqrt{d}} \right)
 
     Args:
-        in_channels (int or tuple): Size of each input sample. A tuple
-            corresponds to the sizes of source and target dimensionalities.
+        in_channels (int or tuple): Size of each input sample, or :obj:`-1` to
+            derive the size from the first input(s) to the forward method.
+            A tuple corresponds to the sizes of source and target
+            dimensionalities.
         out_channels (int): Size of each output sample.
         heads (int, optional): Number of multi-head-attentions.
             (default: :obj:`1`)
@@ -45,8 +49,8 @@ class TransformerConv(MessagePassing):
                 \alpha_{i,j} \mathbf{W}_2 \vec{x}_j \right)}_{=\mathbf{m}_i}
 
             with :math:`\beta_i = \textrm{sigmoid}(\mathbf{w}_5^{\top}
-            [ \mathbf{x}_i, \mathbf{m}_i, \mathbf{x}_i - \mathbf{m}_i ])`
-            (default: :obj:`False`)
+            [ \mathbf{W}_1 \mathbf{x}_i, \mathbf{m}_i, \mathbf{W}_1
+            \mathbf{x}_i - \mathbf{m}_i ])` (default: :obj:`False`)
         dropout (float, optional): Dropout probability of the normalized
             attention coefficients which exposes each node to a stochastically
             sampled neighborhood during training. (default: :obj:`0`)
@@ -82,11 +86,19 @@ class TransformerConv(MessagePassing):
     """
     _alpha: OptTensor
 
-    def __init__(self, in_channels: Union[int, Tuple[int,
-                                                     int]], out_channels: int,
-                 heads: int = 1, concat: bool = True, beta: bool = False,
-                 dropout: float = 0., edge_dim: Optional[int] = None,
-                 bias: bool = True, root_weight: bool = True, **kwargs):
+    def __init__(
+        self,
+        in_channels: Union[int, Tuple[int, int]],
+        out_channels: int,
+        heads: int = 1,
+        concat: bool = True,
+        beta: bool = False,
+        dropout: float = 0.,
+        edge_dim: Optional[int] = None,
+        bias: bool = True,
+        root_weight: bool = True,
+        **kwargs,
+    ):
         kwargs.setdefault('aggr', 'add')
         super(TransformerConv, self).__init__(node_dim=0, **kwargs)
 
@@ -98,6 +110,7 @@ class TransformerConv(MessagePassing):
         self.concat = concat
         self.dropout = dropout
         self.edge_dim = edge_dim
+        self._alpha = None
 
         if isinstance(in_channels, int):
             in_channels = (in_channels, in_channels)
@@ -137,14 +150,34 @@ class TransformerConv(MessagePassing):
             self.lin_beta.reset_parameters()
 
     def forward(self, x: Union[Tensor, PairTensor], edge_index: Adj,
-                edge_attr: OptTensor = None):
-        """"""
+                edge_attr: OptTensor = None, return_attention_weights=None):
+        # type: (Union[Tensor, PairTensor], Tensor, OptTensor, NoneType) -> Tensor  # noqa
+        # type: (Union[Tensor, PairTensor], SparseTensor, OptTensor, NoneType) -> Tensor  # noqa
+        # type: (Union[Tensor, PairTensor], Tensor, OptTensor, bool) -> Tuple[Tensor, Tuple[Tensor, Tensor]]  # noqa
+        # type: (Union[Tensor, PairTensor], SparseTensor, OptTensor, bool) -> Tuple[Tensor, SparseTensor]  # noqa
+        r"""
+        Args:
+            return_attention_weights (bool, optional): If set to :obj:`True`,
+                will additionally return the tuple
+                :obj:`(edge_index, attention_weights)`, holding the computed
+                attention weights for each edge. (default: :obj:`None`)
+        """
+
+        H, C = self.heads, self.out_channels
 
         if isinstance(x, Tensor):
             x: PairTensor = (x, x)
 
-        # propagate_type: (x: PairTensor, edge_attr: OptTensor)
-        out = self.propagate(edge_index, x=x, edge_attr=edge_attr, size=None)
+        query = self.lin_query(x[1]).view(-1, H, C)
+        key = self.lin_key(x[0]).view(-1, H, C)
+        value = self.lin_value(x[0]).view(-1, H, C)
+
+        # propagate_type: (query: Tensor, key:Tensor, value: Tensor, edge_attr: OptTensor) # noqa
+        out = self.propagate(edge_index, query=query, key=key, value=value,
+                             edge_attr=edge_attr, size=None)
+
+        alpha = self._alpha
+        self._alpha = None
 
         if self.concat:
             out = out.view(-1, self.heads * self.out_channels)
@@ -158,35 +191,39 @@ class TransformerConv(MessagePassing):
                 beta = beta.sigmoid()
                 out = beta * x_r + (1 - beta) * out
             else:
-                out += x_r
+                out = out + x_r
 
-        return out
+        if isinstance(return_attention_weights, bool):
+            assert alpha is not None
+            if isinstance(edge_index, Tensor):
+                return out, (edge_index, alpha)
+            elif isinstance(edge_index, SparseTensor):
+                return out, edge_index.set_value(alpha, layout='coo')
+        else:
+            return out
 
-    def message(self, x_i: Tensor, x_j: Tensor, edge_attr: OptTensor,
-                index: Tensor, ptr: OptTensor,
+    def message(self, query_i: Tensor, key_j: Tensor, value_j: Tensor,
+                edge_attr: OptTensor, index: Tensor, ptr: OptTensor,
                 size_i: Optional[int]) -> Tensor:
 
-        query = self.lin_query(x_i).view(-1, self.heads, self.out_channels)
-        key = self.lin_key(x_j).view(-1, self.heads, self.out_channels)
-
         if self.lin_edge is not None:
             assert edge_attr is not None
             edge_attr = self.lin_edge(edge_attr).view(-1, self.heads,
                                                       self.out_channels)
-            key += edge_attr
+            key_j = key_j + edge_attr
 
-        alpha = (query * key).sum(dim=-1) / math.sqrt(self.out_channels)
+        alpha = (query_i * key_j).sum(dim=-1) / math.sqrt(self.out_channels)
         alpha = softmax(alpha, index, ptr, size_i)
+        self._alpha = alpha
         alpha = F.dropout(alpha, p=self.dropout, training=self.training)
 
-        out = self.lin_value(x_j).view(-1, self.heads, self.out_channels)
+        out = value_j
         if edge_attr is not None:
-            out += edge_attr
+            out = out + edge_attr
 
-        out *= alpha.view(-1, self.heads, 1)
+        out = out * alpha.view(-1, self.heads, 1)
         return out
 
-    def __repr__(self):
-        return '{}({}, {}, heads={})'.format(self.__class__.__name__,
-                                             self.in_channels,
-                                             self.out_channels, self.heads)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({self.in_channels}, '
+                f'{self.out_channels}, heads={self.heads})')
