@@ -1,11 +1,14 @@
-from typing import Optional
-
 from math import ceil
+from typing import Optional
 
 import torch
 from torch import Tensor
-from torch.nn import Sequential as S, Linear as L, BatchNorm1d as BN
-from torch.nn import ELU, Conv1d
+from torch.nn import ELU
+from torch.nn import BatchNorm1d as BN
+from torch.nn import Conv1d
+from torch.nn import Linear as L
+from torch.nn import Sequential as S
+
 from torch_geometric.nn import Reshape
 
 from ..inits import reset
@@ -55,11 +58,19 @@ class XConv(torch.nn.Module):
         num_workers (int): Number of workers to use for k-NN computation.
             Has no effect in case :obj:`batch` is not :obj:`None`, or the input
             lies on the GPU. (default: :obj:`1`)
+
+    Shapes:
+        - **input:**
+          node features :math:`(|\mathcal{V}|, F_{in})`,
+          positions :math:`(|\mathcal{V}|, D)`,
+          batch vector :math:`(|\mathcal{V}|)` *(optional)*
+        - **output:**
+          node features :math:`(|\mathcal{V}|, F_{out})`
     """
     def __init__(self, in_channels: int, out_channels: int, dim: int,
                  kernel_size: int, hidden_channels: Optional[int] = None,
                  dilation: int = 1, bias: bool = True, num_workers: int = 1):
-        super(XConv, self).__init__()
+        super().__init__()
 
         if knn_graph is None:
             raise ImportError('`XConv` requires `torch-cluster`.')
@@ -148,6 +159,6 @@ class XConv(torch.nn.Module):
 
         return out
 
-    def __repr__(self):
-        return '{}({}, {})'.format(self.__class__.__name__, self.in_channels,
-                                   self.out_channels)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({self.in_channels}, '
+                f'{self.out_channels})')
