@@ -1,10 +1,9 @@
-from torch_geometric.typing import Adj, OptTensor
-
 import torch
-from torch import Tensor
 import torch.nn.functional as F
+from torch import Tensor
 
 from torch_geometric.nn.models import LabelPropagation
+from torch_geometric.typing import Adj, OptTensor
 
 
 class CorrectAndSmooth(torch.nn.Module):
@@ -67,7 +66,7 @@ class CorrectAndSmooth(torch.nn.Module):
     def __init__(self, num_correction_layers: int, correction_alpha: float,
                  num_smoothing_layers: int, smoothing_alpha: float,
                  autoscale: bool = True, scale: float = 1.0):
-        super(CorrectAndSmooth, self).__init__()
+        super().__init__()
         self.autoscale = autoscale
         self.scale = scale
 
@@ -88,12 +87,11 @@ class CorrectAndSmooth(torch.nn.Module):
             edge_weight (Tensor, optional): The edge weights.
                 (default: :obj:`None`)
         """
-        assert abs((float(y_soft.sum()) / y_soft.size(0)) - 1.0) < 1e-2
 
         numel = int(mask.sum()) if mask.dtype == torch.bool else mask.size(0)
         assert y_true.size(0) == numel
 
-        if y_true.dtype == torch.long:
+        if y_true.dtype == torch.long and y_true.size(0) == y_true.numel():
             y_true = F.one_hot(y_true.view(-1), y_soft.size(-1))
             y_true = y_true.to(y_soft.dtype)
 
@@ -126,7 +124,7 @@ class CorrectAndSmooth(torch.nn.Module):
         numel = int(mask.sum()) if mask.dtype == torch.bool else mask.size(0)
         assert y_true.size(0) == numel
 
-        if y_true.dtype == torch.long:
+        if y_true.dtype == torch.long and y_true.size(0) == y_true.numel():
             y_true = F.one_hot(y_true.view(-1), y_soft.size(-1))
             y_true = y_true.to(y_soft.dtype)
 
