@@ -1,5 +1,9 @@
+from typing import Optional
+
 import torch
 import torch.nn.functional as F
+from torch import Tensor
+from torch.nn import Module
 from torch.utils.checkpoint import checkpoint
 
 
@@ -29,7 +33,7 @@ class DeepGCNLayer(torch.nn.Module):
 
         For an example of using :obj:`GENConv`, see
         `examples/ogbn_proteins_deepgcn.py
-        <https://github.com/rusty1s/pytorch_geometric/blob/master/examples/
+        <https://github.com/pyg-team/pytorch_geometric/blob/master/examples/
         ogbn_proteins_deepgcn.py>`_.
 
     Args:
@@ -40,7 +44,7 @@ class DeepGCNLayer(torch.nn.Module):
         block (string, optional): The skip connection operation to use
             (:obj:`"res+"`, :obj:`"res"`, :obj:`"dense"` or :obj:`"plain"`).
             (default: :obj:`"res+"`)
-        dropout: (float, optional): Whether to apply or dropout.
+        dropout (float, optional): Whether to apply or dropout.
             (default: :obj:`0.`)
         ckpt_grad (bool, optional): If set to :obj:`True`, will checkpoint this
             part of the model. Checkpointing works by trading compute for
@@ -48,9 +52,16 @@ class DeepGCNLayer(torch.nn.Module):
             memory. Set this to :obj:`True` in case you encounter out-of-memory
             errors while going deep. (default: :obj:`False`)
     """
-    def __init__(self, conv=None, norm=None, act=None, block='res+',
-                 dropout=0., ckpt_grad=False):
-        super(DeepGCNLayer, self).__init__()
+    def __init__(
+        self,
+        conv: Optional[Module] = None,
+        norm: Optional[Module] = None,
+        act: Optional[Module] = None,
+        block: str = 'res+',
+        dropout: float = 0.,
+        ckpt_grad: bool = False,
+    ):
+        super().__init__()
 
         self.conv = conv
         self.norm = norm
@@ -64,7 +75,7 @@ class DeepGCNLayer(torch.nn.Module):
         self.conv.reset_parameters()
         self.norm.reset_parameters()
 
-    def forward(self, *args, **kwargs):
+    def forward(self, *args, **kwargs) -> Tensor:
         """"""
         args = list(args)
         x = args.pop(0)
@@ -102,5 +113,5 @@ class DeepGCNLayer(torch.nn.Module):
 
             return F.dropout(h, p=self.dropout, training=self.training)
 
-    def __repr__(self):
-        return '{}(block={})'.format(self.__class__.__name__, self.block)
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}(block={self.block})'
