@@ -1,5 +1,4 @@
 from typing import Dict, List, Optional, Tuple
-from torch_geometric.typing import NodeType, EdgeType, OptTensor
 
 import torch
 from torch import Tensor
@@ -7,6 +6,8 @@ from torch.nn import Embedding
 from torch.utils.data import DataLoader
 from torch_sparse import SparseTensor
 
+from torch_geometric.typing import EdgeType, NodeType, OptTensor
+
 EPS = 1e-15
 
 
@@ -79,7 +80,11 @@ class MetaPath2Vec(torch.nn.Module):
             adj = adj.to('cpu')
             adj_dict[keys] = adj
 
-        assert walk_length >= context_size
+        assert walk_length + 1 >= context_size
+        if walk_length > len(metapath) and metapath[0][0] != metapath[-1][-1]:
+            raise AttributeError(
+                "The 'walk_length' is longer than the given 'metapath', but "
+                "the 'metapath' does not denote a cycle")
 
         self.adj_dict = adj_dict
         self.embedding_dim = embedding_dim
@@ -107,7 +112,9 @@ class MetaPath2Vec(torch.nn.Module):
         assert len(offset) == walk_length + 1
         self.offset = torch.tensor(offset)
 
-        self.embedding = Embedding(count, embedding_dim, sparse=sparse)
+        # + 1 denotes a dummy node used to link to for isolated nodes.
+        self.embedding = Embedding(count + 1, embedding_dim, sparse=sparse)
+        self.dummy_idx = count
 
         self.reset_parameters()
 
@@ -118,7 +125,7 @@ class MetaPath2Vec(torch.nn.Module):
         r"""Returns the embeddings for the nodes in :obj:`batch` of type
         :obj:`node_type`."""
         emb = self.embedding.weight[self.start[node_type]:self.end[node_type]]
-        return emb if batch is None else emb[batch]
+        return emb if batch is None else emb.index_select(0, batch)
 
     def loader(self, **kwargs):
         r"""Returns the data loader that creates both positive and negative
@@ -140,11 +147,13 @@ class MetaPath2Vec(torch.nn.Module):
         for i in range(self.walk_length):
             keys = self.metapath[i % len(self.metapath)]
             adj = self.adj_dict[keys]
-            batch = adj.sample(num_neighbors=1, subset=batch).squeeze()
+            batch = sample(adj, batch, num_neighbors=1,
+                           dummy_idx=self.dummy_idx).view(-1)
             rws.append(batch)
 
         rw = torch.stack(rws, dim=-1)
         rw.add_(self.offset.view(1, -1))
+        rw[rw > self.dummy_idx] = self.dummy_idx
 
         walks = []
         num_walks_per_rw = 1 + self.walk_length + 1 - self.context_size
@@ -172,7 +181,8 @@ class MetaPath2Vec(torch.nn.Module):
         return torch.cat(walks, dim=0)
 
     def _sample(self, batch: List[int]) -> Tuple[Tensor, Tensor]:
-        batch = torch.tensor(batch, dtype=torch.long)
+        if not isinstance(batch, Tensor):
+            batch = torch.tensor(batch, dtype=torch.long)
         return self._pos_sample(batch), self._neg_sample(batch)
 
     def loss(self, pos_rw: Tensor, neg_rw: Tensor) -> Tensor:
@@ -203,7 +213,7 @@ class MetaPath2Vec(torch.nn.Module):
         return pos_loss + neg_loss
 
     def test(self, train_z: Tensor, train_y: Tensor, test_z: Tensor,
-             test_y: Tensor, solver: str = 'lbfgs', multi_class: str = 'auto',
+             test_y: Tensor, solver: str = "lbfgs", multi_class: str = "auto",
              *args, **kwargs) -> float:
         r"""Evaluates latent space quality via a logistic regression downstream
         task."""
@@ -216,5 +226,26 @@ class MetaPath2Vec(torch.nn.Module):
                          test_y.detach().cpu().numpy())
 
     def __repr__(self) -> str:
-        return (f'{self.__class__.__name__}({self.embedding.weight.size(0)}, '
+        return (f'{self.__class__.__name__}('
+                f'{self.embedding.weight.size(0) - 1}, '
                 f'{self.embedding.weight.size(1)})')
+
+
+def sample(src: SparseTensor, subset: Tensor, num_neighbors: int,
+           dummy_idx: int) -> Tensor:
+
+    mask = subset < dummy_idx
+    rowcount = torch.zeros_like(subset)
+    rowcount[mask] = src.storage.rowcount()[subset[mask]]
+    mask = mask & (rowcount > 0)
+    offset = torch.zeros_like(subset)
+    offset[mask] = src.storage.rowptr()[subset[mask]]
+
+    rand = torch.rand((rowcount.size(0), num_neighbors), device=subset.device)
+    rand.mul_(rowcount.to(rand.dtype).view(-1, 1))
+    rand = rand.to(torch.long)
+    rand.add_(offset.view(-1, 1))
+
+    col = src.storage.col()[rand]
+    col[~mask] = dummy_idx
+    return col
