@@ -1,11 +1,16 @@
+from typing import Optional, Tuple
+
 import scipy.sparse
 import torch
 import torch.nn.functional as F
+from torch import Tensor
 from torch_sparse import coalesce
-from torch_geometric.nn import SignedConv
 
-from torch_geometric.utils import (negative_sampling,
-                                   structured_negative_sampling)
+from torch_geometric.nn import SignedConv
+from torch_geometric.utils import (
+    negative_sampling,
+    structured_negative_sampling,
+)
 
 
 class SignedGCN(torch.nn.Module):
@@ -23,9 +28,15 @@ class SignedGCN(torch.nn.Module):
         bias (bool, optional): If set to :obj:`False`, all layers will not
             learn an additive bias. (default: :obj:`True`)
     """
-    def __init__(self, in_channels, hidden_channels, num_layers, lamb=5,
-                 bias=True):
-        super(SignedGCN, self).__init__()
+    def __init__(
+        self,
+        in_channels: int,
+        hidden_channels: int,
+        num_layers: int,
+        lamb: float = 5,
+        bias: bool = True,
+    ):
+        super().__init__()
 
         self.in_channels = in_channels
         self.hidden_channels = hidden_channels
@@ -50,7 +61,11 @@ class SignedGCN(torch.nn.Module):
             conv.reset_parameters()
         self.lin.reset_parameters()
 
-    def split_edges(self, edge_index, test_ratio=0.2):
+    def split_edges(
+        self,
+        edge_index: Tensor,
+        test_ratio: float = 0.2,
+    ) -> Tuple[Tensor, Tensor]:
         r"""Splits the edges :obj:`edge_index` into train and test edges.
 
         Args:
@@ -66,8 +81,12 @@ class SignedGCN(torch.nn.Module):
 
         return train_edge_index, test_edge_index
 
-    def create_spectral_features(self, pos_edge_index, neg_edge_index,
-                                 num_nodes=None):
+    def create_spectral_features(
+        self,
+        pos_edge_index: Tensor,
+        neg_edge_index: Tensor,
+        num_nodes: Optional[int] = None,
+    ) -> Tensor:
         r"""Creates :obj:`in_channels` spectral node features based on
         positive and negative edges.
 
@@ -105,7 +124,12 @@ class SignedGCN(torch.nn.Module):
         x = svd.components_.T
         return torch.from_numpy(x).to(torch.float).to(pos_edge_index.device)
 
-    def forward(self, x, pos_edge_index, neg_edge_index):
+    def forward(
+        self,
+        x: Tensor,
+        pos_edge_index: Tensor,
+        neg_edge_index: Tensor,
+    ) -> Tensor:
         """Computes node embeddings :obj:`z` based on positive edges
         :obj:`pos_edge_index` and negative edges :obj:`neg_edge_index`.
 
@@ -119,7 +143,7 @@ class SignedGCN(torch.nn.Module):
             z = F.relu(conv(z, pos_edge_index, neg_edge_index))
         return z
 
-    def discriminate(self, z, edge_index):
+    def discriminate(self, z: Tensor, edge_index: Tensor) -> Tensor:
         """Given node embeddings :obj:`z`, classifies the link relation
         between node pairs :obj:`edge_index` to be either positive,
         negative or non-existent.
@@ -132,7 +156,12 @@ class SignedGCN(torch.nn.Module):
         value = self.lin(value)
         return torch.log_softmax(value, dim=1)
 
-    def nll_loss(self, z, pos_edge_index, neg_edge_index):
+    def nll_loss(
+        self,
+        z: Tensor,
+        pos_edge_index: Tensor,
+        neg_edge_index: Tensor,
+    ) -> Tensor:
         """Computes the discriminator loss based on node embeddings :obj:`z`,
         and positive edges :obj:`pos_edge_index` and negative nedges
         :obj:`neg_edge_index`.
@@ -158,7 +187,11 @@ class SignedGCN(torch.nn.Module):
             none_edge_index.new_full((none_edge_index.size(1), ), 2))
         return nll_loss / 3.0
 
-    def pos_embedding_loss(self, z, pos_edge_index):
+    def pos_embedding_loss(
+        self,
+        z: Tensor,
+        pos_edge_index: Tensor,
+    ) -> Tensor:
         """Computes the triplet loss between positive node pairs and sampled
         non-node pairs.
 
@@ -171,7 +204,7 @@ class SignedGCN(torch.nn.Module):
         out = (z[i] - z[j]).pow(2).sum(dim=1) - (z[i] - z[k]).pow(2).sum(dim=1)
         return torch.clamp(out, min=0).mean()
 
-    def neg_embedding_loss(self, z, neg_edge_index):
+    def neg_embedding_loss(self, z: Tensor, neg_edge_index: Tensor) -> Tensor:
         """Computes the triplet loss between negative node pairs and sampled
         non-node pairs.
 
@@ -184,7 +217,12 @@ class SignedGCN(torch.nn.Module):
         out = (z[i] - z[k]).pow(2).sum(dim=1) - (z[i] - z[j]).pow(2).sum(dim=1)
         return torch.clamp(out, min=0).mean()
 
-    def loss(self, z, pos_edge_index, neg_edge_index):
+    def loss(
+        self,
+        z: Tensor,
+        pos_edge_index: Tensor,
+        neg_edge_index: Tensor,
+    ) -> Tensor:
         """Computes the overall objective.
 
         Args:
@@ -197,7 +235,12 @@ class SignedGCN(torch.nn.Module):
         loss_2 = self.neg_embedding_loss(z, neg_edge_index)
         return nll_loss + self.lamb * (loss_1 + loss_2)
 
-    def test(self, z, pos_edge_index, neg_edge_index):
+    def test(
+        self,
+        z: Tensor,
+        pos_edge_index: Tensor,
+        neg_edge_index: Tensor,
+    ) -> Tuple[float, float]:
         """Evaluates node embeddings :obj:`z` on positive and negative test
         edges by computing AUC and F1 scores.
 
@@ -206,7 +249,7 @@ class SignedGCN(torch.nn.Module):
             pos_edge_index (LongTensor): The positive edge indices.
             neg_edge_index (LongTensor): The negative edge indices.
         """
-        from sklearn.metrics import roc_auc_score, f1_score
+        from sklearn.metrics import f1_score, roc_auc_score
 
         with torch.no_grad():
             pos_p = self.discriminate(z, pos_edge_index)[:, :2].max(dim=1)[1]
@@ -222,8 +265,6 @@ class SignedGCN(torch.nn.Module):
 
         return auc, f1
 
-    def __repr__(self):
-        return '{}({}, {}, num_layers={})'.format(self.__class__.__name__,
-                                                  self.in_channels,
-                                                  self.hidden_channels,
-                                                  self.num_layers)
+    def __repr__(self) -> str:
+        return (f'{self.__class__.__name__}({self.in_channels}, '
+                f'{self.hidden_channels}, num_layers={self.num_layers})')
