@@ -3,7 +3,7 @@ from typing import Callable, Tuple
 
 import torch
 from torch import Tensor
-from torch.nn import Linear, GRUCell
+from torch.nn import GRUCell, Linear
 from torch_scatter import scatter, scatter_max
 
 from torch_geometric.nn.inits import zeros
@@ -35,7 +35,7 @@ class TGNMemory(torch.nn.Module):
     def __init__(self, num_nodes: int, raw_msg_dim: int, memory_dim: int,
                  time_dim: int, message_module: Callable,
                  aggregator_module: Callable):
-        super(TGNMemory, self).__init__()
+        super().__init__()
 
         self.num_nodes = num_nodes
         self.raw_msg_dim = raw_msg_dim
@@ -137,7 +137,8 @@ class TGNMemory(torch.nn.Module):
         memory = self.gru(aggr, self.memory[n_id])
 
         # Get local copy of updated `last_update`.
-        last_update = self.last_update.scatter(0, idx, t)[n_id]
+        dim_size = self.last_update.size(0)
+        last_update = scatter_max(t, idx, dim=0, dim_size=dim_size)[0][n_id]
 
         return memory, last_update
 
@@ -168,12 +169,12 @@ class TGNMemory(torch.nn.Module):
             self.__update_memory__(
                 torch.arange(self.num_nodes, device=self.memory.device))
             self.__reset_message_store__()
-        super(TGNMemory, self).train(mode)
+        super().train(mode)
 
 
 class IdentityMessage(torch.nn.Module):
     def __init__(self, raw_msg_dim: int, memory_dim: int, time_dim: int):
-        super(IdentityMessage, self).__init__()
+        super().__init__()
         self.out_channels = raw_msg_dim + 2 * memory_dim + time_dim
 
     def forward(self, z_src, z_dst, raw_msg, t_enc):
@@ -196,7 +197,7 @@ class MeanAggregator(torch.nn.Module):
 
 class TimeEncoder(torch.nn.Module):
     def __init__(self, out_channels):
-        super(TimeEncoder, self).__init__()
+        super().__init__()
         self.out_channels = out_channels
         self.lin = Linear(1, out_channels)
 
