@@ -1,9 +1,9 @@
-from torch_geometric.typing import OptTensor
-
 import torch.nn.functional as F
 from torch import Tensor
 from torch.nn.modules.instancenorm import _InstanceNorm
 from torch_scatter import scatter
+
+from torch_geometric.typing import OptTensor
 from torch_geometric.utils import degree
 
 
@@ -36,10 +36,16 @@ class InstanceNorm(_InstanceNorm):
             uses instance statistics in both training and eval modes.
             (default: :obj:`False`)
     """
-    def __init__(self, in_channels, eps=1e-5, momentum=0.1, affine=False,
-                 track_running_stats=False):
-        super(InstanceNorm, self).__init__(in_channels, eps, momentum, affine,
-                                           track_running_stats)
+    def __init__(
+        self,
+        in_channels: int,
+        eps: float = 1e-5,
+        momentum: float = 0.1,
+        affine: bool = False,
+        track_running_stats: bool = False,
+    ):
+        super().__init__(in_channels, eps, momentum, affine,
+                         track_running_stats)
 
     def forward(self, x: Tensor, batch: OptTensor = None) -> Tensor:
         """"""
@@ -62,7 +68,7 @@ class InstanceNorm(_InstanceNorm):
             mean = scatter(x, batch, dim=0, dim_size=batch_size,
                            reduce='add') / norm
 
-            x = x - mean[batch]
+            x = x - mean.index_select(0, batch)
 
             var = scatter(x * x, batch, dim=0, dim_size=batch_size,
                           reduce='add')
@@ -83,14 +89,14 @@ class InstanceNorm(_InstanceNorm):
             if self.running_var is not None:
                 var = self.running_var.view(1, -1).expand(batch_size, -1)
 
-            x = x - mean[batch]
+            x = x - mean.index_select(0, batch)
 
-        out = x / (var.sqrt()[batch] + self.eps)
+        out = x / (var + self.eps).sqrt().index_select(0, batch)
 
         if self.weight is not None and self.bias is not None:
             out = out * self.weight.view(1, -1) + self.bias.view(1, -1)
 
         return out
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f'{self.__class__.__name__}({self.num_features})'
