@@ -1,10 +1,18 @@
-from collections import namedtuple
+from typing import Callable, List, NamedTuple, Optional, Tuple
 
 import torch
 import torch.nn.functional as F
+from torch import Tensor
 from torch_scatter import scatter_add
-from torch_sparse import coalesce
-from torch_geometric.utils import softmax
+
+from torch_geometric.utils import coalesce, softmax
+
+
+class UnpoolInfo(NamedTuple):
+    edge_index: Tensor
+    cluster: Tensor
+    batch: Tensor
+    new_edge_score: Tensor
 
 
 class EdgePooling(torch.nn.Module):
@@ -21,7 +29,7 @@ class EdgePooling(torch.nn.Module):
     Contraction" paper, use either
     :func:`EdgePooling.compute_edge_score_softmax`
     or :func:`EdgePooling.compute_edge_score_tanh`, and set
-    :obj:`add_to_edge_score` to :obj:`0`.
+    :obj:`add_to_edge_score` to :obj:`0.0`.
 
     To duplicate the configuration from the "Edge Contraction Pooling for
     Graph Neural Networks" paper, set :obj:`dropout` to :obj:`0.2`.
@@ -41,19 +49,19 @@ class EdgePooling(torch.nn.Module):
             :func:`EdgePooling.compute_edge_score_sigmoid`.
             (default: :func:`EdgePooling.compute_edge_score_softmax`)
         dropout (float, optional): The probability with
-            which to drop edge scores during training. (default: :obj:`0`)
+            which to drop edge scores during training. (default: :obj:`0.0`)
         add_to_edge_score (float, optional): This is added to each
             computed edge score. Adding this greatly helps with unpool
             stability. (default: :obj:`0.5`)
     """
-
-    unpool_description = namedtuple(
-        "UnpoolDescription",
-        ["edge_index", "cluster", "batch", "new_edge_score"])
-
-    def __init__(self, in_channels, edge_score_method=None, dropout=0,
-                 add_to_edge_score=0.5):
-        super(EdgePooling, self).__init__()
+    def __init__(
+        self,
+        in_channels: int,
+        edge_score_method: Optional[Callable] = None,
+        dropout: Optional[float] = 0.0,
+        add_to_edge_score: float = 0.5,
+    ):
+        super().__init__()
         self.in_channels = in_channels
         if edge_score_method is None:
             edge_score_method = self.compute_edge_score_softmax
@@ -69,18 +77,35 @@ class EdgePooling(torch.nn.Module):
         self.lin.reset_parameters()
 
     @staticmethod
-    def compute_edge_score_softmax(raw_edge_score, edge_index, num_nodes):
+    def compute_edge_score_softmax(
+        raw_edge_score: Tensor,
+        edge_index: Tensor,
+        num_nodes: int,
+    ) -> Tensor:
         return softmax(raw_edge_score, edge_index[1], num_nodes=num_nodes)
 
     @staticmethod
-    def compute_edge_score_tanh(raw_edge_score, edge_index, num_nodes):
+    def compute_edge_score_tanh(
+        raw_edge_score: Tensor,
+        edge_index: Optional[Tensor] = None,
+        num_nodes: Optional[int] = None,
+    ) -> Tensor:
         return torch.tanh(raw_edge_score)
 
     @staticmethod
-    def compute_edge_score_sigmoid(raw_edge_score, edge_index, num_nodes):
+    def compute_edge_score_sigmoid(
+        raw_edge_score: Tensor,
+        edge_index: Optional[Tensor] = None,
+        num_nodes: Optional[int] = None,
+    ) -> Tensor:
         return torch.sigmoid(raw_edge_score)
 
-    def forward(self, x, edge_index, batch):
+    def forward(
+        self,
+        x: Tensor,
+        edge_index: Tensor,
+        batch: Tensor,
+    ) -> Tuple[Tensor, Tensor, Tensor, UnpoolInfo]:
         r"""Forward computation which computes the raw edge score, normalizes
         it, and merges the edges.
 
@@ -95,7 +120,7 @@ class EdgePooling(torch.nn.Module):
             * **x** *(Tensor)* - The pooled node features.
             * **edge_index** *(LongTensor)* - The coarsened edge indices.
             * **batch** *(LongTensor)* - The coarsened batch vector.
-            * **unpool_info** *(unpool_description)* - Information that is
+            * **unpool_info** *(UnpoolInfo)* - Information that is
               consumed by :func:`EdgePooling.unpool` for unpooling.
         """
         e = torch.cat([x[edge_index[0]], x[edge_index[1]]], dim=-1)
@@ -109,65 +134,72 @@ class EdgePooling(torch.nn.Module):
 
         return x, edge_index, batch, unpool_info
 
-    def __merge_edges__(self, x, edge_index, batch, edge_score):
-        nodes_remaining = set(range(x.size(0)))
+    def __merge_edges__(
+        self,
+        x: Tensor,
+        edge_index: Tensor,
+        batch: Tensor,
+        edge_score: Tensor,
+    ) -> Tuple[Tensor, Tensor, Tensor, UnpoolInfo]:
 
-        cluster = torch.empty_like(batch, device=torch.device('cpu'))
-        edge_argsort = torch.argsort(edge_score, descending=True)
+        cluster = torch.empty_like(batch)
+        perm: List[int] = torch.argsort(edge_score, descending=True).tolist()
 
         # Iterate through all edges, selecting it if it is not incident to
         # another already chosen edge.
+        mask = torch.ones(x.size(0), dtype=torch.bool)
+
         i = 0
-        new_edge_indices = []
+        new_edge_indices: List[int] = []
         edge_index_cpu = edge_index.cpu()
-        for edge_idx in edge_argsort.tolist():
-            source = edge_index_cpu[0, edge_idx].item()
-            if source not in nodes_remaining:
+        for edge_idx in perm:
+            source = int(edge_index_cpu[0, edge_idx])
+            if not bool(mask[source]):
                 continue
 
-            target = edge_index_cpu[1, edge_idx].item()
-            if target not in nodes_remaining:
+            target = int(edge_index_cpu[1, edge_idx])
+            if not bool(mask[target]):
                 continue
 
             new_edge_indices.append(edge_idx)
 
             cluster[source] = i
-            nodes_remaining.remove(source)
+            mask[source] = False
 
             if source != target:
                 cluster[target] = i
-                nodes_remaining.remove(target)
+                mask[target] = False
 
             i += 1
 
-        # The remaining nodes are simply kept.
-        for node_idx in nodes_remaining:
-            cluster[node_idx] = i
-            i += 1
-        cluster = cluster.to(x.device)
+        # The remaining nodes are simply kept:
+        j = int(mask.sum())
+        cluster[mask] = torch.arange(i, i + j, device=x.device)
+        i += j
 
         # We compute the new features as an addition of the old ones.
         new_x = scatter_add(x, cluster, dim=0, dim_size=i)
         new_edge_score = edge_score[new_edge_indices]
-        if len(nodes_remaining) > 0:
+        if int(mask.sum()) > 0:
             remaining_score = x.new_ones(
                 (new_x.size(0) - len(new_edge_indices), ))
             new_edge_score = torch.cat([new_edge_score, remaining_score])
         new_x = new_x * new_edge_score.view(-1, 1)
 
-        N = new_x.size(0)
-        new_edge_index, _ = coalesce(cluster[edge_index], None, N, N)
-
+        new_edge_index = coalesce(cluster[edge_index], num_nodes=new_x.size(0))
         new_batch = x.new_empty(new_x.size(0), dtype=torch.long)
         new_batch = new_batch.scatter_(0, cluster, batch)
 
-        unpool_info = self.unpool_description(edge_index=edge_index,
-                                              cluster=cluster, batch=batch,
-                                              new_edge_score=new_edge_score)
+        unpool_info = UnpoolInfo(edge_index=edge_index, cluster=cluster,
+                                 batch=batch, new_edge_score=new_edge_score)
 
         return new_x, new_edge_index, new_batch, unpool_info
 
-    def unpool(self, x, unpool_info):
+    def unpool(
+        self,
+        x: Tensor,
+        unpool_info: UnpoolInfo,
+    ) -> Tuple[Tensor, Tensor, Tensor]:
         r"""Unpools a previous edge pooling step.
 
         For unpooling, :obj:`x` should be of same shape as those produced by
@@ -176,7 +208,7 @@ class EdgePooling(torch.nn.Module):
 
         Args:
             x (Tensor): The node features.
-            unpool_info (unpool_description): Information that has
+            unpool_info (UnpoolInfo): Information that has
                 been produced by :func:`EdgePooling.forward`.
 
         Return types:
@@ -184,10 +216,9 @@ class EdgePooling(torch.nn.Module):
             * **edge_index** *(LongTensor)* - The new edge indices.
             * **batch** *(LongTensor)* - The new batch vector.
         """
-
         new_x = x / unpool_info.new_edge_score.view(-1, 1)
         new_x = new_x[unpool_info.cluster]
         return new_x, unpool_info.edge_index, unpool_info.batch
 
-    def __repr__(self):
-        return '{}({})'.format(self.__class__.__name__, self.in_channels)
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}({self.in_channels})'
