@@ -1,16 +1,21 @@
+from typing import Optional
+
+import torch
+
 try:
     from torch_cluster import graclus_cluster
 except ImportError:
     graclus_cluster = None
 
 
-def graclus(edge_index, weight=None, num_nodes=None):
+def graclus(edge_index, weight: Optional[torch.Tensor] = None,
+            num_nodes: Optional[int] = None):
     r"""A greedy clustering algorithm from the `"Weighted Graph Cuts without
     Eigenvectors: A Multilevel Approach" <http://www.cs.utexas.edu/users/
     inderjit/public_papers/multilevel_pami.pdf>`_ paper of picking an unmarked
     vertex and matching it with one of its unmarked neighbors (that maximizes
     its edge weight).
-    The GPU algoithm is adapted from the `"A GPU Algorithm for Greedy Graph
+    The GPU algorithm is adapted from the `"A GPU Algorithm for Greedy Graph
     Matching" <http://www.staff.science.uu.nl/~bisse101/Articles/match12.pdf>`_
     paper.
 
@@ -27,5 +32,4 @@ def graclus(edge_index, weight=None, num_nodes=None):
     if graclus_cluster is None:
         raise ImportError('`graclus` requires `torch-cluster`.')
 
-    row, col = edge_index
-    return graclus_cluster(row, col, weight, num_nodes)
+    return graclus_cluster(edge_index[0], edge_index[1], weight, num_nodes)
