@@ -1,6 +1,11 @@
+from typing import Callable, Optional, Tuple, Union
+
 import torch
+from torch import Tensor
+
 from torch_geometric.nn import GraphConv
-from torch_geometric.nn.pool.topk_pool import topk, filter_adj
+from torch_geometric.nn.pool.topk_pool import filter_adj, topk
+from torch_geometric.typing import OptTensor
 from torch_geometric.utils import softmax
 
 
@@ -31,17 +36,17 @@ class SAGPooling(torch.nn.Module):
 
             \mathbf{X}^{\prime} &= (\mathbf{X} \odot \mathbf{y})_{\mathbf{i}}
 
-            \mathbf{A}^{\prime} &= \mathbf{A}_{\mathbf{i},\mathbf{i}},
+            \mathbf{A}^{\prime} &= \mathbf{A}_{\mathbf{i},\mathbf{i}}.
 
-    where nodes are dropped based on a learnable projection score
-    :math:`\mathbf{p}`.
     Projections scores are learned based on a graph neural network layer.
 
     Args:
         in_channels (int): Size of each input sample.
-        ratio (float): Graph pooling ratio, which is used to compute
-            :math:`k = \lceil \mathrm{ratio} \cdot N \rceil`.
-            This value is ignored if min_score is not None.
+        ratio (float or int): Graph pooling ratio, which is used to compute
+            :math:`k = \lceil \mathrm{ratio} \cdot N \rceil`, or the value
+            of :math:`k` itself, depending on whether the type of :obj:`ratio`
+            is :obj:`float` or :obj:`int`.
+            This value is ignored if :obj:`min_score` is not :obj:`None`.
             (default: :obj:`0.5`)
         GNN (torch.nn.Module, optional): A graph neural network layer for
             calculating projection scores (one of
@@ -63,9 +68,17 @@ class SAGPooling(torch.nn.Module):
         **kwargs (optional): Additional parameters for initializing the graph
             neural network layer.
     """
-    def __init__(self, in_channels, ratio=0.5, GNN=GraphConv, min_score=None,
-                 multiplier=1, nonlinearity=torch.tanh, **kwargs):
-        super(SAGPooling, self).__init__()
+    def __init__(
+        self,
+        in_channels: int,
+        ratio: Union[float, int] = 0.5,
+        GNN: torch.nn.Module = GraphConv,
+        min_score: Optional[float] = None,
+        multiplier: float = 1.0,
+        nonlinearity: Callable = torch.tanh,
+        **kwargs,
+    ):
+        super().__init__()
 
         self.in_channels = in_channels
         self.ratio = ratio
@@ -79,7 +92,14 @@ class SAGPooling(torch.nn.Module):
     def reset_parameters(self):
         self.gnn.reset_parameters()
 
-    def forward(self, x, edge_index, edge_attr=None, batch=None, attn=None):
+    def forward(
+        self,
+        x: Tensor,
+        edge_index: Tensor,
+        edge_attr: OptTensor = None,
+        batch: OptTensor = None,
+        attn: OptTensor = None,
+    ) -> Tuple[Tensor, Tensor, OptTensor, Tensor, Tensor, Tensor]:
         """"""
         if batch is None:
             batch = edge_index.new_zeros(x.size(0))
@@ -103,10 +123,11 @@ class SAGPooling(torch.nn.Module):
 
         return x, edge_index, edge_attr, batch, perm, score[perm]
 
-    def __repr__(self):
-        return '{}({}, {}, {}={}, multiplier={})'.format(
-            self.__class__.__name__, self.gnn.__class__.__name__,
-            self.in_channels,
-            'ratio' if self.min_score is None else 'min_score',
-            self.ratio if self.min_score is None else self.min_score,
-            self.multiplier)
+    def __repr__(self) -> str:
+        if self.min_score is None:
+            ratio = f'ratio={self.ratio}'
+        else:
+            ratio = f'min_score={self.min_score}'
+
+        return (f'{self.__class__.__name__}({self.gnn.__class__.__name__}, '
+                f'{self.in_channels}, {ratio}, multiplier={self.multiplier})')
