@@ -1,21 +1,21 @@
-from typing import List, Dict, Union, Optional, Any
-from torch_geometric.typing import NodeType, EdgeType, Metadata
-
 import copy
 import warnings
+from typing import Any, Dict, List, Optional, Union
 
 import torch
 from torch import Tensor
 from torch.nn import Module, Parameter
 from torch_sparse import SparseTensor
 
-from torch_geometric.nn.fx import Transformer
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.nn.dense import Linear
+from torch_geometric.nn.fx import Transformer
+from torch_geometric.typing import EdgeType, Metadata, NodeType
+from torch_geometric.utils.hetero import get_unused_node_types
 
 try:
-    from torch.fx import GraphModule, Graph, Node
-except ImportError:
+    from torch.fx import Graph, GraphModule, Node
+except (ImportError, ModuleNotFoundError, AttributeError):
     GraphModule, Graph, Node = 'GraphModule', 'Graph', 'Node'
 
 
@@ -43,6 +43,7 @@ def to_hetero_with_bases(module: Module, metadata: Metadata, num_bases: int,
 
         class GNN(torch.nn.Module):
             def __init__(self):
+                super().__init__()
                 self.conv1 = SAGEConv((16, 16), 32)
                 self.conv2 = SAGEConv((32, 32), 32)
 
@@ -56,7 +57,7 @@ def to_hetero_with_bases(module: Module, metadata: Metadata, num_bases: int,
         node_types = ['paper', 'author']
         edge_types = [
             ('paper', 'cites', 'paper'),
-            ('paper' 'written_by', 'author'),
+            ('paper', 'written_by', 'author'),
             ('author', 'writes', 'paper'),
         ]
         metadata = (node_types, edge_types)
@@ -125,7 +126,7 @@ def to_hetero_with_bases(module: Module, metadata: Metadata, num_bases: int,
             In case :obj:`input_map` is not further specified, will try to
             automatically determine the correct type of input arguments.
             (default: :obj:`None`)
-        debug: (bool, optional): If set to :obj:`True`, will perform
+        debug (bool, optional): If set to :obj:`True`, will perform
             transformation in debug mode. (default: :obj:`False`)
     """
     transformer = ToHeteroWithBasesTransformer(module, metadata, num_bases,
@@ -144,16 +145,37 @@ class ToHeteroWithBasesTransformer(Transformer):
         debug: bool = False,
     ):
         super().__init__(module, input_map, debug)
+
         self.metadata = metadata
         self.num_bases = num_bases
         self.in_channels = in_channels or {}
         assert len(metadata) == 2
         assert len(metadata[0]) > 0 and len(metadata[1]) > 0
 
+        self.validate()
+
         # Compute IDs for each node and edge type:
         self.node_type2id = {k: i for i, k in enumerate(metadata[0])}
         self.edge_type2id = {k: i for i, k in enumerate(metadata[1])}
 
+    def validate(self):
+        unused_node_types = get_unused_node_types(*self.metadata)
+        if len(unused_node_types) > 0:
+            warnings.warn(
+                f"There exist node types ({unused_node_types}) whose "
+                f"representations do not get updated during message passing "
+                f"as they do not occur as destination type in any edge type. "
+                f"This may lead to unexpected behaviour.")
+
+        names = self.metadata[0] + [rel for _, rel, _ in self.metadata[1]]
+        for name in names:
+            if not name.isidentifier():
+                warnings.warn(
+                    f"The type '{name}' contains invalid characters which "
+                    f"may lead to unexpected behaviour. To avoid any issues, "
+                    f"ensure that your types only contain letters, numbers "
+                    f"and underscores.")
+
     def transform(self) -> GraphModule:
         self._node_offset_dict_initialized = False
         self._edge_offset_dict_initialized = False
@@ -393,7 +415,6 @@ def get_node_offset_dict(
     input_dict: Dict[NodeType, Union[Tensor, SparseTensor]],
     type2id: Dict[NodeType, int],
 ) -> Dict[NodeType, int]:
-
     cumsum = 0
     out: Dict[NodeType, int] = {}
     for key in type2id.keys():
@@ -406,7 +427,6 @@ def get_edge_offset_dict(
     input_dict: Dict[EdgeType, Union[Tensor, SparseTensor]],
     type2id: Dict[EdgeType, int],
 ) -> Dict[EdgeType, int]:
-
     cumsum = 0
     out: Dict[EdgeType, int] = {}
     for key in type2id.keys():
@@ -536,4 +556,5 @@ def split_output(
 
 
 def key2str(key: Union[NodeType, EdgeType]) -> str:
-    return '__'.join(key) if isinstance(key, tuple) else key
+    key = '__'.join(key) if isinstance(key, tuple) else key
+    return key.replace(' ', '_').replace('-', '_').replace(':', '_')
