@@ -1,22 +1,25 @@
 import torch
 
-from torch_geometric.utils import to_undirected
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
+from torch_geometric.utils import to_undirected
 
 
+@functional_transform('face_to_edge')
 class FaceToEdge(BaseTransform):
     r"""Converts mesh faces :obj:`[3, num_faces]` to edge indices
-    :obj:`[2, num_edges]`.
+    :obj:`[2, num_edges]` (functional name: :obj:`face_to_edge`).
 
     Args:
         remove_faces (bool, optional): If set to :obj:`False`, the face tensor
             will not be removed.
     """
-    def __init__(self, remove_faces=True):
+    def __init__(self, remove_faces: bool = True):
         self.remove_faces = remove_faces
 
-    def __call__(self, data):
-        if data.face is not None:
+    def __call__(self, data: Data) -> Data:
+        if hasattr(data, 'face'):
             face = data.face
             edge_index = torch.cat([face[:2], face[1:], face[::2]], dim=1)
             edge_index = to_undirected(edge_index, num_nodes=data.num_nodes)
@@ -26,6 +29,3 @@ class FaceToEdge(BaseTransform):
                 data.face = None
 
         return data
-
-    def __repr__(self):
-        return '{}()'.format(self.__class__.__name__)
