@@ -1,13 +1,18 @@
-import re
 import math
+import re
 
-import torch
 import numpy as np
+import torch
+
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
+from torch_geometric.transforms import BaseTransform
 
 
-class FixedPoints(object):
+@functional_transform('fixed_points')
+class FixedPoints(BaseTransform):
     r"""Samples a fixed number of :obj:`num` points and features from a point
-    cloud.
+    cloud (functional name: :obj:`fixed_points`).
 
     Args:
         num (int): The number of points to sample.
@@ -22,12 +27,17 @@ class FixedPoints(object):
             In case :obj:`allow_duplicates` is :obj:`True`, the number of
             duplicated points are kept to a minimum. (default: :obj:`False`)
     """
-    def __init__(self, num, replace=True, allow_duplicates=False):
+    def __init__(
+        self,
+        num: int,
+        replace: bool = True,
+        allow_duplicates: bool = False,
+    ):
         self.num = num
         self.replace = replace
         self.allow_duplicates = allow_duplicates
 
-    def __call__(self, data):
+    def __call__(self, data: Data) -> Data:
         num_nodes = data.num_nodes
 
         if self.replace:
@@ -42,14 +52,15 @@ class FixedPoints(object):
             ], dim=0)[:self.num]
 
         for key, item in data:
-            if bool(re.search('edge', key)):
+            if key == 'num_nodes':
+                data.num_nodes = choice.size(0)
+            elif bool(re.search('edge', key)):
                 continue
-            if (torch.is_tensor(item) and item.size(0) == num_nodes
-                    and item.size(0) != 1):
+            elif (torch.is_tensor(item) and item.size(0) == num_nodes
+                  and item.size(0) != 1):
                 data[key] = item[choice]
 
         return data
 
-    def __repr__(self):
-        return '{}({}, replace={})'.format(self.__class__.__name__, self.num,
-                                           self.replace)
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}({self.num}, replace={self.replace})'
