@@ -1,17 +1,23 @@
-import torch
-import numpy as np
-from scipy.linalg import expm
-from torch_sparse import coalesce
-from torch_scatter import scatter_add
+from typing import Any, Dict, List, Tuple
 
+import numpy as np
+import torch
+from scipy.linalg import expm
+from torch import Tensor
+from torch_scatter import scatter_add
+from torch_sparse import coalesce
+
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
 from torch_geometric.utils import add_self_loops, is_undirected, to_dense_adj
 
 
+@functional_transform('gdc')
 class GDC(BaseTransform):
     r"""Processes the graph via Graph Diffusion Convolution (GDC) from the
     `"Diffusion Improves Graph Learning" <https://www.kdd.in.tum.de/gdc>`_
-    paper.
+    paper (functional name: :obj:`gdc`).
 
     .. note::
 
@@ -62,11 +68,16 @@ class GDC(BaseTransform):
 
     :rtype: :class:`torch_geometric.data.Data`
     """
-    def __init__(self, self_loop_weight=1, normalization_in='sym',
-                 normalization_out='col',
-                 diffusion_kwargs=dict(method='ppr', alpha=0.15),
-                 sparsification_kwargs=dict(method='threshold',
-                                            avg_degree=64), exact=True):
+    def __init__(
+        self,
+        self_loop_weight: float = 1.,
+        normalization_in: str = 'sym',
+        normalization_out: str = 'col',
+        diffusion_kwargs: Dict[str, Any] = dict(method='ppr', alpha=0.15),
+        sparsification_kwargs: Dict[str, Any] = dict(method='threshold',
+                                                     avg_degree=64),
+        exact: bool = True,
+    ):
 
         self.__calc_ppr__ = get_calc_ppr()
 
@@ -81,7 +92,7 @@ class GDC(BaseTransform):
             assert exact or self_loop_weight == 1
 
     @torch.no_grad()
-    def __call__(self, data):
+    def __call__(self, data: Data) -> Data:
         N = data.num_nodes
         edge_index = data.edge_index
         if data.edge_attr is None:
@@ -122,8 +133,13 @@ class GDC(BaseTransform):
 
         return data
 
-    def transition_matrix(self, edge_index, edge_weight, num_nodes,
-                          normalization):
+    def transition_matrix(
+        self,
+        edge_index: Tensor,
+        edge_weight: Tensor,
+        num_nodes: int,
+        normalization: str,
+    ) -> Tuple[Tensor, Tensor]:
         r"""Calculate the approximate, sparse diffusion on a given sparse
         matrix.
 
@@ -166,13 +182,18 @@ class GDC(BaseTransform):
             pass
         else:
             raise ValueError(
-                'Transition matrix normalization {} unknown.'.format(
-                    normalization))
+                f"Transition matrix normalization '{normalization}' unknown")
 
         return edge_index, edge_weight
 
-    def diffusion_matrix_exact(self, edge_index, edge_weight, num_nodes,
-                               method, **kwargs):
+    def diffusion_matrix_exact(
+        self,
+        edge_index: Tensor,
+        edge_weight: Tensor,
+        num_nodes: int,
+        method: str,
+        **kwargs,
+    ) -> Tensor:
         r"""Calculate the (dense) diffusion on a given sparse graph.
         Note that these exact variants are not scalable. They densify the
         adjacency matrix and calculate either its inverse or its matrix
@@ -234,12 +255,19 @@ class GDC(BaseTransform):
                 mat = mat @ adj_matrix
                 diff_matrix += coeff * mat
         else:
-            raise ValueError('Exact GDC diffusion {} unknown.'.format(method))
+            raise ValueError(f"Exact GDC diffusion '{method}' unknown")
 
         return diff_matrix
 
-    def diffusion_matrix_approx(self, edge_index, edge_weight, num_nodes,
-                                normalization, method, **kwargs):
+    def diffusion_matrix_approx(
+        self,
+        edge_index: Tensor,
+        edge_weight: Tensor,
+        num_nodes: int,
+        normalization: str,
+        method: str,
+        **kwargs,
+    ) -> Tuple[Tensor, Tensor]:
         r"""Calculate the approximate, sparse diffusion on a given sparse
         graph.
 
@@ -302,8 +330,8 @@ class GDC(BaseTransform):
                 pass
             else:
                 raise ValueError(
-                    ('Transition matrix normalization {} not implemented for '
-                     'non-exact GDC computation.').format(normalization))
+                    f"Transition matrix normalization '{normalization}' not "
+                    f"implemented for non-exact GDC computation")
 
         elif method == 'heat':
             raise NotImplementedError(
@@ -312,17 +340,20 @@ class GDC(BaseTransform):
                  '"Kloster and Gleich: Heat kernel based community detection '
                  '(KDD 2014)."'))
         else:
-            raise ValueError(
-                'Approximate GDC diffusion {} unknown.'.format(method))
+            raise ValueError(f"Approximate GDC diffusion '{method}' unknown")
 
         return edge_index, edge_weight
 
-    def sparsify_dense(self, matrix, method, **kwargs):
+    def sparsify_dense(
+        self,
+        matrix: Tensor,
+        method: str,
+        **kwargs,
+    ) -> Tuple[Tensor, Tensor]:
         r"""Sparsifies the given dense matrix.
 
         Args:
             matrix (Tensor): Matrix to sparsify.
-            num_nodes (int): Number of nodes.
             method (str): Method of sparsification. Options:
 
                 1. :obj:`"threshold"`: Remove all edges with weights smaller
@@ -359,32 +390,37 @@ class GDC(BaseTransform):
             edge_weight = matrix.flatten()[edge_index_flat]
 
         elif method == 'topk':
-            assert kwargs['dim'] in [0, 1]
-            sort_idx = torch.argsort(matrix, dim=kwargs['dim'],
-                                     descending=True)
-            if kwargs['dim'] == 0:
-                top_idx = sort_idx[:kwargs['k']]
-                edge_weight = torch.gather(matrix, dim=kwargs['dim'],
+            k, dim = min(N, kwargs['k']), kwargs['dim']
+            assert dim in [0, 1]
+            sort_idx = torch.argsort(matrix, dim=dim, descending=True)
+            if dim == 0:
+                top_idx = sort_idx[:k]
+                edge_weight = torch.gather(matrix, dim=dim,
                                            index=top_idx).flatten()
 
-                row_idx = torch.arange(0, N, device=matrix.device).repeat(
-                    kwargs['k'])
+                row_idx = torch.arange(0, N, device=matrix.device).repeat(k)
                 edge_index = torch.stack([top_idx.flatten(), row_idx], dim=0)
             else:
-                top_idx = sort_idx[:, :kwargs['k']]
-                edge_weight = torch.gather(matrix, dim=kwargs['dim'],
+                top_idx = sort_idx[:, :k]
+                edge_weight = torch.gather(matrix, dim=dim,
                                            index=top_idx).flatten()
 
                 col_idx = torch.arange(
-                    0, N, device=matrix.device).repeat_interleave(kwargs['k'])
+                    0, N, device=matrix.device).repeat_interleave(k)
                 edge_index = torch.stack([col_idx, top_idx.flatten()], dim=0)
         else:
-            raise ValueError('GDC sparsification {} unknown.'.format(method))
+            raise ValueError(f"GDC sparsification '{method}' unknown")
 
         return edge_index, edge_weight
 
-    def sparsify_sparse(self, edge_index, edge_weight, num_nodes, method,
-                        **kwargs):
+    def sparsify_sparse(
+        self,
+        edge_index: Tensor,
+        edge_weight: Tensor,
+        num_nodes: int,
+        method: str,
+        **kwargs,
+    ) -> Tuple[Tensor, Tensor]:
         r"""Sparsifies a given sparse graph further.
 
         Args:
@@ -416,13 +452,13 @@ class GDC(BaseTransform):
             edge_weight = edge_weight[remaining_edge_idx]
         elif method == 'topk':
             raise NotImplementedError(
-                'Sparse topk sparsification not implemented.')
+                'Sparse topk sparsification not implemented')
         else:
-            raise ValueError('GDC sparsification {} unknown.'.format(method))
+            raise ValueError(f"GDC sparsification '{method}' unknown")
 
         return edge_index, edge_weight
 
-    def __expm__(self, matrix, symmetric):
+    def __expm__(self, matrix: Tensor, symmetric: bool) -> Tensor:
         r"""Calculates matrix exponential.
 
         Args:
@@ -432,14 +468,19 @@ class GDC(BaseTransform):
         :rtype: (:class:`Tensor`)
         """
         if symmetric:
-            e, V = torch.symeig(matrix, eigenvectors=True)
+            e, V = torch.linalg.eigh(matrix, UPLO='U')
             diff_mat = V @ torch.diag(e.exp()) @ V.t()
         else:
             diff_mat_np = expm(matrix.cpu().numpy())
             diff_mat = torch.Tensor(diff_mat_np).to(matrix.device)
         return diff_mat
 
-    def __calculate_eps__(self, matrix, num_nodes, avg_degree):
+    def __calculate_eps__(
+        self,
+        matrix: Tensor,
+        num_nodes: int,
+        avg_degree: int,
+    ) -> float:
         r"""Calculates threshold necessary to achieve a given average degree.
 
         Args:
@@ -457,8 +498,13 @@ class GDC(BaseTransform):
         right = sorted_edges[avg_degree * num_nodes]
         return (left + right) / 2.0
 
-    def __neighbors_to_graph__(self, neighbors, neighbor_weights,
-                               normalization='row', device='cpu'):
+    def __neighbors_to_graph__(
+        self,
+        neighbors: List[List[int]],
+        neighbor_weights: List[List[float]],
+        normalization: str = 'row',
+        device: torch.device = 'cpu',
+    ) -> Tuple[Tensor, Tensor]:
         r"""Combine a list of neighbors and neighbor weights to create a sparse
         graph.
 
@@ -475,7 +521,7 @@ class GDC(BaseTransform):
         """
         edge_weight = torch.Tensor(np.concatenate(neighbor_weights)).to(device)
         i = np.repeat(np.arange(len(neighbors)),
-                      np.fromiter(map(len, neighbors), dtype=np.int))
+                      np.fromiter(map(len, neighbors), dtype=int))
         j = np.concatenate(neighbors)
         if normalization == 'col':
             edge_index = torch.Tensor(np.vstack([j, i])).to(device)
@@ -488,15 +534,18 @@ class GDC(BaseTransform):
                 f"PPR matrix normalization {normalization} unknown.")
         return edge_index, edge_weight
 
-    def __repr__(self):
-        return '{}()'.format(self.__class__.__name__)
-
 
 def get_calc_ppr():
     import numba
 
     @numba.jit(nopython=True, parallel=True)
-    def calc_ppr(indptr, indices, out_degree, alpha, eps):
+    def calc_ppr(
+        indptr: np.ndarray,
+        indices: np.ndarray,
+        out_degree: np.ndarray,
+        alpha: float,
+        eps: float,
+    ) -> Tuple[List[List[int]], List[List[float]]]:
         r"""Calculate the personalized PageRank vector for all nodes
         using a variant of the Andersen algorithm
         (see Andersen et al. :Local Graph Partitioning using PageRank Vectors.)
