@@ -1,13 +1,16 @@
 import torch
 from torch_scatter import scatter_max
 
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
 
 
+@functional_transform('local_cartesian')
 class LocalCartesian(BaseTransform):
     r"""Saves the relative Cartesian coordinates of linked nodes in its edge
-    attributes. Each coordinate gets *neighborhood-normalized* to the
-    interval :math:`{[0, 1]}^D`.
+    attributes (functional name: :obj:`local_cartesian`). Each coordinate gets
+    *neighborhood-normalized* to the interval :math:`{[0, 1]}^D`.
 
     Args:
         norm (bool, optional): If set to :obj:`False`, the output will not be
@@ -16,11 +19,11 @@ class LocalCartesian(BaseTransform):
         cat (bool, optional): If set to :obj:`False`, all existing edge
             attributes will be replaced. (default: :obj:`True`)
     """
-    def __init__(self, norm=True, cat=True):
+    def __init__(self, norm: bool = True, cat: bool = True):
         self.norm = norm
         self.cat = cat
 
-    def __call__(self, data):
+    def __call__(self, data: Data) -> Data:
         (row, col), pos, pseudo = data.edge_index, data.pos, data.edge_attr
 
         cart = pos[row] - pos[col]
@@ -41,6 +44,3 @@ class LocalCartesian(BaseTransform):
             data.edge_attr = cart
 
         return data
-
-    def __repr__(self):
-        return '{}()'.format(self.__class__.__name__)
