@@ -1,11 +1,15 @@
 import torch
 import torch.nn.functional as F
 
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
 
 
+@functional_transform('normalize_rotation')
 class NormalizeRotation(BaseTransform):
-    r"""Rotates all points according to the eigenvectors of the point cloud.
+    r"""Rotates all points according to the eigenvectors of the point cloud
+    (functional name: :obj:`normalize_rotation`).
     If the data additionally holds normals saved in :obj:`data.normal`, these
     will be rotated accordingly.
 
@@ -20,7 +24,7 @@ class NormalizeRotation(BaseTransform):
         self.max_points = max_points
         self.sort = sort
 
-    def __call__(self, data):
+    def __call__(self, data: Data) -> Data:
         pos = data.pos
 
         if self.max_points > 0 and pos.size(0) > self.max_points:
@@ -29,7 +33,8 @@ class NormalizeRotation(BaseTransform):
 
         pos = pos - pos.mean(dim=0, keepdim=True)
         C = torch.matmul(pos.t(), pos)
-        e, v = torch.eig(C, eigenvectors=True)  # v[:,j] is j-th eigenvector
+        e, v = torch.linalg.eig(C)  # v[:,j] is j-th eigenvector
+        e, v = torch.view_as_real(e), v.real
 
         if self.sort:
             indices = e[:, 0].argsort(descending=True)
@@ -41,6 +46,3 @@ class NormalizeRotation(BaseTransform):
             data.normal = F.normalize(torch.matmul(data.normal, v))
 
         return data
-
-    def __repr__(self):
-        return '{}()'.format(self.__class__.__name__)
