@@ -1,10 +1,17 @@
+from typing import Union
+
 import torch
-from torch_geometric.transforms import LinearTransformation
+
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
+from torch_geometric.transforms import BaseTransform, LinearTransformation
 
 
-class RandomShear(object):
+@functional_transform('random_shear')
+class RandomShear(BaseTransform):
     r"""Shears node positions by randomly sampled factors :math:`s` within a
     given interval, *e.g.*, resulting in the transformation matrix
+    (functional name: :obj:`random_shear`)
 
     .. math::
         \begin{bmatrix}
@@ -19,11 +26,10 @@ class RandomShear(object):
         shear (float or int): maximum shearing factor defining the range
             :math:`(-\mathrm{shear}, +\mathrm{shear})` to sample from.
     """
-
-    def __init__(self, shear):
+    def __init__(self, shear: Union[float, int]):
         self.shear = abs(shear)
 
-    def __call__(self, data):
+    def __call__(self, data: Data) -> Data:
         dim = data.pos.size(-1)
 
         matrix = data.pos.new_empty(dim, dim).uniform_(-self.shear, self.shear)
@@ -32,5 +38,5 @@ class RandomShear(object):
 
         return LinearTransformation(matrix)(data)
 
-    def __repr__(self):
-        return '{}({})'.format(self.__class__.__name__, self.shear)
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}({self.shear})'
