@@ -1,18 +1,20 @@
 import torch
 
 from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
 
 
+@functional_transform('svd_feature_reduction')
 class SVDFeatureReduction(BaseTransform):
     r"""Dimensionality reduction of node features via Singular Value
-    Decomposition (SVD).
+    Decomposition (SVD) (functional name: :obj:`svd_feature_reduction`).
 
     Args:
         out_channels (int): The dimensionlity of node features after
             reduction.
     """
-    def __init__(self, out_channels):
+    def __init__(self, out_channels: int):
         self.out_channels = out_channels
 
     def __call__(self, data: Data) -> Data:
