@@ -1,13 +1,17 @@
 import torch
-from torch_sparse import spspmm, coalesce
+from torch_sparse import coalesce, spspmm
 
-from torch_geometric.utils import remove_self_loops
+from torch_geometric.data import Data
+from torch_geometric.data.datapipes import functional_transform
 from torch_geometric.transforms import BaseTransform
+from torch_geometric.utils import remove_self_loops
 
 
+@functional_transform('two_hop')
 class TwoHop(BaseTransform):
-    r"""Adds the two hop edges to the edge indices."""
-    def __call__(self, data):
+    r"""Adds the two hop edges to the edge indices
+    (functional name: :obj:`two_hop`)."""
+    def __call__(self, data: Data) -> Data:
         edge_index, edge_attr = data.edge_index, data.edge_attr
         N = data.num_nodes
 
@@ -28,6 +32,3 @@ class TwoHop(BaseTransform):
             data.edge_attr = edge_attr
 
         return data
-
-    def __repr__(self):
-        return '{}()'.format(self.__class__.__name__)
