@@ -1,19 +1,26 @@
 from .degree import degree
 from .softmax import softmax
-from .dropout import dropout_adj
+from .dropout import dropout_adj, dropout_node, dropout_edge, dropout_path
+from .augmentation import shuffle_node, mask_feature, add_random_edge
 from .sort_edge_index import sort_edge_index
 from .coalesce import coalesce
 from .undirected import is_undirected, to_undirected
 from .loop import (contains_self_loops, remove_self_loops,
                    segregate_self_loops, add_self_loops,
-                   add_remaining_self_loops)
+                   add_remaining_self_loops, get_self_loop_attr)
 from .isolated import contains_isolated_nodes, remove_isolated_nodes
-from .subgraph import subgraph, k_hop_subgraph
+from .subgraph import (get_num_hops, subgraph, k_hop_subgraph,
+                       bipartite_subgraph)
 from .homophily import homophily
+from .assortativity import assortativity
 from .get_laplacian import get_laplacian
+from .get_mesh_laplacian import get_mesh_laplacian
+from .mask import index_to_mask, mask_to_index
 from .to_dense_batch import to_dense_batch
 from .to_dense_adj import to_dense_adj
-from .sparse import dense_to_sparse
+from .sparse import (dense_to_sparse, is_sparse, is_torch_sparse_tensor,
+                     to_torch_coo_tensor)
+from .unbatch import unbatch, unbatch_edge_index
 from .normalized_cut import normalized_cut
 from .grid import grid
 from .geodesic import geodesic_distance
@@ -22,20 +29,26 @@ from .convert import to_scipy_sparse_matrix, from_scipy_sparse_matrix
 from .convert import to_networkx, from_networkx
 from .convert import to_trimesh, from_trimesh
 from .convert import to_cugraph
+from .smiles import from_smiles, to_smiles
 from .random import (erdos_renyi_graph, stochastic_blockmodel_graph,
                      barabasi_albert_graph)
-from .negative_sampling import (negative_sampling,
+from .negative_sampling import (negative_sampling, batched_negative_sampling,
                                 structured_negative_sampling,
-                                batched_negative_sampling)
+                                structured_negative_sampling_feasible)
 from .train_test_split_edges import train_test_split_edges
-from .metric import (accuracy, true_positive, true_negative, false_positive,
-                     false_negative, precision, recall, f1_score,
-                     intersection_and_union, mean_iou)
+from .scatter import scatter
+from .spmm import spmm
 
 __all__ = [
     'degree',
     'softmax',
+    'dropout_node',
+    'dropout_edge',
+    'dropout_path',
     'dropout_adj',
+    'shuffle_node',
+    'mask_feature',
+    'add_random_edge',
     'sort_edge_index',
     'coalesce',
     'is_undirected',
@@ -45,15 +58,24 @@ __all__ = [
     'segregate_self_loops',
     'add_self_loops',
     'add_remaining_self_loops',
+    'get_self_loop_attr',
     'contains_isolated_nodes',
     'remove_isolated_nodes',
+    'get_num_hops',
     'subgraph',
+    'bipartite_subgraph',
     'k_hop_subgraph',
     'homophily',
+    'assortativity',
     'get_laplacian',
+    'get_mesh_laplacian',
+    'index_to_mask',
+    'mask_to_index',
     'to_dense_batch',
     'to_dense_adj',
     'dense_to_sparse',
+    'unbatch',
+    'unbatch_edge_index',
     'normalized_cut',
     'grid',
     'geodesic_distance',
@@ -65,23 +87,21 @@ __all__ = [
     'to_trimesh',
     'from_trimesh',
     'to_cugraph',
+    'from_smiles',
+    'to_smiles',
     'erdos_renyi_graph',
     'stochastic_blockmodel_graph',
     'barabasi_albert_graph',
     'negative_sampling',
-    'structured_negative_sampling',
     'batched_negative_sampling',
+    'structured_negative_sampling',
+    'structured_negative_sampling_feasible',
     'train_test_split_edges',
-    'accuracy',
-    'true_positive',
-    'true_negative',
-    'false_positive',
-    'false_negative',
-    'precision',
-    'recall',
-    'f1_score',
-    'intersection_and_union',
-    'mean_iou',
+    'scatter',
+    'is_torch_sparse_tensor',
+    'is_sparse',
+    'to_torch_coo_tensor',
+    'spmm',
 ]
 
 classes = __all__
