@@ -1,18 +1,21 @@
-from typing import Optional, Union, Tuple, List
-
 from collections import defaultdict
+from typing import Any, Iterable, List, Optional, Tuple, Union
 
-import torch
 import scipy.sparse
+import torch
 from torch import Tensor
-from torch.utils.dlpack import to_dlpack, from_dlpack
+from torch.utils.dlpack import from_dlpack, to_dlpack
 
-import torch_geometric.data
+import torch_geometric
 
 from .num_nodes import maybe_num_nodes
 
 
-def to_scipy_sparse_matrix(edge_index, edge_attr=None, num_nodes=None):
+def to_scipy_sparse_matrix(
+    edge_index: Tensor,
+    edge_attr: Optional[Tensor] = None,
+    num_nodes: Optional[int] = None,
+) -> scipy.sparse.coo_matrix:
     r"""Converts a graph given by edge indices and edge attributes to a scipy
     sparse matrix.
 
@@ -22,6 +25,16 @@ def to_scipy_sparse_matrix(edge_index, edge_attr=None, num_nodes=None):
             edge features. (default: :obj:`None`)
         num_nodes (int, optional): The number of nodes, *i.e.*
             :obj:`max_val + 1` of :attr:`index`. (default: :obj:`None`)
+
+    Examples:
+
+        >>> edge_index = torch.tensor([
+        ...     [0, 1, 1, 2, 2, 3],
+        ...     [1, 0, 2, 1, 3, 2],
+        ... ])
+        >>> to_scipy_sparse_matrix(edge_index)
+        <4x4 sparse matrix of type '<class 'numpy.float32'>'
+            with 6 stored elements in COOrdinate format>
     """
     row, col = edge_index.cpu()
 
@@ -37,11 +50,25 @@ def to_scipy_sparse_matrix(edge_index, edge_attr=None, num_nodes=None):
     return out
 
 
-def from_scipy_sparse_matrix(A):
+def from_scipy_sparse_matrix(
+        A: scipy.sparse.spmatrix) -> Tuple[Tensor, Tensor]:
     r"""Converts a scipy sparse matrix to edge indices and edge attributes.
 
     Args:
         A (scipy.sparse): A sparse matrix.
+
+    Examples:
+
+        >>> edge_index = torch.tensor([
+        ...     [0, 1, 1, 2, 2, 3],
+        ...     [1, 0, 2, 1, 3, 2],
+        ... ])
+        >>> adj = to_scipy_sparse_matrix(edge_index)
+        >>> # `edge_index` and `edge_weight` are both returned
+        >>> from_scipy_sparse_matrix(adj)
+        (tensor([[0, 1, 1, 2, 2, 3],
+                [1, 0, 2, 1, 3, 2]]),
+        tensor([1., 1., 1., 1., 1., 1.]))
     """
     A = A.tocoo()
     row = torch.from_numpy(A.row).to(torch.long)
@@ -51,8 +78,14 @@ def from_scipy_sparse_matrix(A):
     return edge_index, edge_weight
 
 
-def to_networkx(data, node_attrs=None, edge_attrs=None, to_undirected=False,
-                remove_self_loops=False):
+def to_networkx(
+    data: 'torch_geometric.data.Data',
+    node_attrs: Optional[Iterable[str]] = None,
+    edge_attrs: Optional[Iterable[str]] = None,
+    graph_attrs: Optional[Iterable[str]] = None,
+    to_undirected: Optional[Union[bool, str]] = False,
+    remove_self_loops: bool = False,
+) -> Any:
     r"""Converts a :class:`torch_geometric.data.Data` instance to a
     :obj:`networkx.Graph` if :attr:`to_undirected` is set to :obj:`True`, or
     a directed :obj:`networkx.DiGraph` otherwise.
@@ -63,36 +96,56 @@ def to_networkx(data, node_attrs=None, edge_attrs=None, to_undirected=False,
             copied. (default: :obj:`None`)
         edge_attrs (iterable of str, optional): The edge attributes to be
             copied. (default: :obj:`None`)
-        to_undirected (bool, optional): If set to :obj:`True`, will return a
-            a :obj:`networkx.Graph` instead of a :obj:`networkx.DiGraph`. The
-            undirected graph will correspond to the upper triangle of the
-            corresponding adjacency matrix. (default: :obj:`False`)
+        graph_attrs (iterable of str, optional): The graph attributes to be
+            copied. (default: :obj:`None`)
+        to_undirected (bool or str, optional): If set to :obj:`True` or
+            "upper", will return a :obj:`networkx.Graph` instead of a
+            :obj:`networkx.DiGraph`. The undirected graph will correspond to
+            the upper triangle of the corresponding adjacency matrix.
+            Similarly, if set to "lower", the undirected graph will correspond
+            to the lower triangle of the adjacency matrix. (default:
+            :obj:`False`)
         remove_self_loops (bool, optional): If set to :obj:`True`, will not
             include self loops in the resulting graph. (default: :obj:`False`)
+
+    Examples:
+
+        >>> edge_index = torch.tensor([
+        ...     [0, 1, 1, 2, 2, 3],
+        ...     [1, 0, 2, 1, 3, 2],
+        ... ])
+        >>> data = Data(edge_index=edge_index, num_nodes=4)
+        >>> to_networkx(data)
+        <networkx.classes.digraph.DiGraph at 0x2713fdb40d0>
+
     """
     import networkx as nx
 
-    if to_undirected:
-        G = nx.Graph()
-    else:
-        G = nx.DiGraph()
+    G = nx.Graph() if to_undirected else nx.DiGraph()
 
     G.add_nodes_from(range(data.num_nodes))
 
-    node_attrs, edge_attrs = node_attrs or [], edge_attrs or []
+    node_attrs = node_attrs or []
+    edge_attrs = edge_attrs or []
+    graph_attrs = graph_attrs or []
 
     values = {}
-    for key, item in data(*(node_attrs + edge_attrs)):
-        if torch.is_tensor(item):
-            values[key] = item.squeeze().tolist()
+    for key, value in data(*(node_attrs + edge_attrs + graph_attrs)):
+        if torch.is_tensor(value):
+            value = value if value.dim() <= 1 else value.squeeze(-1)
+            values[key] = value.tolist()
         else:
-            values[key] = item
-        if isinstance(values[key], (list, tuple)) and len(values[key]) == 1:
-            values[key] = item[0]
+            values[key] = value
+
+    to_undirected = "upper" if to_undirected is True else to_undirected
+    to_undirected_upper = True if to_undirected == "upper" else False
+    to_undirected_lower = True if to_undirected == "lower" else False
 
     for i, (u, v) in enumerate(data.edge_index.t().tolist()):
 
-        if to_undirected and v > u:
+        if to_undirected_upper and u > v:
+            continue
+        elif to_undirected_lower and u < v:
             continue
 
         if remove_self_loops and u == v:
@@ -107,11 +160,17 @@ def to_networkx(data, node_attrs=None, edge_attrs=None, to_undirected=False,
         for i, feat_dict in G.nodes(data=True):
             feat_dict.update({key: values[key][i]})
 
+    for key in graph_attrs:
+        G.graph[key] = values[key]
+
     return G
 
 
-def from_networkx(G, group_node_attrs: Optional[Union[List[str], all]] = None,
-                  group_edge_attrs: Optional[Union[List[str], all]] = None):
+def from_networkx(
+    G: Any,
+    group_node_attrs: Optional[Union[List[str], all]] = None,
+    group_edge_attrs: Optional[Union[List[str], all]] = None,
+) -> 'torch_geometric.data.Data':
     r"""Converts a :obj:`networkx.Graph` or :obj:`networkx.DiGraph` to a
     :class:`torch_geometric.data.Data` instance.
 
@@ -127,12 +186,32 @@ def from_networkx(G, group_node_attrs: Optional[Union[List[str], all]] = None,
 
         All :attr:`group_node_attrs` and :attr:`group_edge_attrs` values must
         be numeric.
+
+    Examples:
+
+        >>> edge_index = torch.tensor([
+        ...     [0, 1, 1, 2, 2, 3],
+        ...     [1, 0, 2, 1, 3, 2],
+        ... ])
+        >>> data = Data(edge_index=edge_index, num_nodes=4)
+        >>> g = to_networkx(data)
+        >>> # A `Data` object is returned
+        >>> from_networkx(g)
+        Data(edge_index=[2, 6], num_nodes=4)
     """
     import networkx as nx
 
+    from torch_geometric.data import Data
+
     G = nx.convert_node_labels_to_integers(G)
     G = G.to_directed() if not nx.is_directed(G) else G
-    edge_index = torch.LongTensor(list(G.edges)).t().contiguous()
+
+    if isinstance(G, (nx.MultiGraph, nx.MultiDiGraph)):
+        edges = list(G.edges(keys=False))
+    else:
+        edges = list(G.edges)
+
+    edge_index = torch.tensor(edges, dtype=torch.long).t().contiguous()
 
     data = defaultdict(list)
 
@@ -156,32 +235,50 @@ def from_networkx(G, group_node_attrs: Optional[Union[List[str], all]] = None,
         if set(feat_dict.keys()) != set(edge_attrs):
             raise ValueError('Not all edges contain the same attributes')
         for key, value in feat_dict.items():
+            key = f'edge_{key}' if key in node_attrs else key
             data[str(key)].append(value)
 
+    for key, value in G.graph.items():
+        key = f'graph_{key}' if key in node_attrs else key
+        data[str(key)] = value
+
     for key, value in data.items():
-        try:
-            data[key] = torch.tensor(value)
-        except ValueError:
-            pass
+        if isinstance(value, (tuple, list)) and isinstance(value[0], Tensor):
+            data[key] = torch.stack(value, dim=0)
+        else:
+            try:
+                data[key] = torch.tensor(value)
+            except (ValueError, TypeError):
+                pass
 
     data['edge_index'] = edge_index.view(2, -1)
-    data = torch_geometric.data.Data.from_dict(data)
-    if data.x is None:
-        data.num_nodes = G.number_of_nodes()
+    data = Data.from_dict(data)
 
     if group_node_attrs is all:
         group_node_attrs = list(node_attrs)
     if group_node_attrs is not None:
-        xs = [data[key] for key in group_node_attrs]
-        xs = [x.view(-1, 1) if x.dim() <= 1 else x for x in xs]
+        xs = []
+        for key in group_node_attrs:
+            x = data[key]
+            x = x.view(-1, 1) if x.dim() <= 1 else x
+            xs.append(x)
+            del data[key]
         data.x = torch.cat(xs, dim=-1)
 
     if group_edge_attrs is all:
         group_edge_attrs = list(edge_attrs)
     if group_edge_attrs is not None:
-        edge_attrs = [data[key] for key in group_edge_attrs]
-        edge_attrs = [x.view(-1, 1) if x.dim() <= 1 else x for x in edge_attrs]
-        data.edge_attr = torch.cat(edge_attrs, dim=-1)
+        xs = []
+        for key in group_edge_attrs:
+            key = f'edge_{key}' if key in node_attrs else key
+            x = data[key]
+            x = x.view(-1, 1) if x.dim() <= 1 else x
+            xs.append(x)
+            del data[key]
+        data.edge_attr = torch.cat(xs, dim=-1)
+
+    if data.x is None and data.pos is None:
+        data.num_nodes = G.number_of_nodes()
 
     return data
 
@@ -192,6 +289,16 @@ def to_trimesh(data):
 
     Args:
         data (torch_geometric.data.Data): The data object.
+
+    Example:
+
+        >>> pos = torch.tensor([[0, 0, 0], [1, 0, 0], [0, 1, 0], [1, 1, 0]],
+        ...                    dtype=torch.float)
+        >>> face = torch.tensor([[0, 1, 2], [1, 2, 3]]).t()
+
+        >>> data = Data(pos=pos, face=face)
+        >>> to_trimesh(data)
+        <trimesh.Trimesh(vertices.shape=(4, 3), faces.shape=(2, 3))>
     """
     import trimesh
     return trimesh.Trimesh(vertices=data.pos.detach().cpu().numpy(),
@@ -205,11 +312,26 @@ def from_trimesh(mesh):
 
     Args:
         mesh (trimesh.Trimesh): A :obj:`trimesh` mesh.
+
+Example:
+
+    Example:
+
+        >>> pos = torch.tensor([[0, 0, 0], [1, 0, 0], [0, 1, 0], [1, 1, 0]],
+        ...                    dtype=torch.float)
+        >>> face = torch.tensor([[0, 1, 2], [1, 2, 3]]).t()
+
+        >>> data = Data(pos=pos, face=face)
+        >>> mesh = to_trimesh(data)
+        >>> from_trimesh(mesh)
+        Data(pos=[4, 3], face=[3, 2])
     """
+    from torch_geometric.data import Data
+
     pos = torch.from_numpy(mesh.vertices).to(torch.float)
     face = torch.from_numpy(mesh.faces).t().contiguous()
 
-    return torch_geometric.data.Data(pos=pos, face=face)
+    return Data(pos=pos, face=face)
 
 
 def to_cugraph(edge_index: Tensor, edge_weight: Optional[Tensor] = None,
