@@ -1,12 +1,13 @@
 from typing import Optional
 
 import torch
+from torch import Tensor
 
 from .num_nodes import maybe_num_nodes
 
 
-def degree(index, num_nodes: Optional[int] = None,
-           dtype: Optional[int] = None):
+def degree(index: Tensor, num_nodes: Optional[int] = None,
+           dtype: Optional[torch.dtype] = None) -> Tensor:
     r"""Computes the (unweighted) degree of a given one-dimensional index
     tensor.
 
@@ -18,6 +19,12 @@ def degree(index, num_nodes: Optional[int] = None,
             returned tensor.
 
     :rtype: :class:`Tensor`
+
+    Example:
+
+        >>> row = torch.tensor([0, 1, 0, 2, 0])
+        >>> degree(row, dtype=torch.long)
+        tensor([3, 1, 1])
     """
     N = maybe_num_nodes(index, num_nodes)
     out = torch.zeros((N, ), dtype=dtype, device=index.device)
