@@ -1,12 +1,30 @@
 from copy import copy
-from typing import Optional
+from typing import Optional  # noqa
 
 import torch
+from torch import Tensor
+from torch_sparse import SparseTensor  # noqa
 
 
-def maybe_num_nodes(index: torch.Tensor,
-                    num_nodes: Optional[int] = None) -> int:
-    return int(index.max()) + 1 if num_nodes is None else num_nodes
+@torch.jit._overload
+def maybe_num_nodes(edge_index, num_nodes=None):
+    # type: (Tensor, Optional[int]) -> int
+    pass
+
+
+@torch.jit._overload
+def maybe_num_nodes(edge_index, num_nodes=None):
+    # type: (SparseTensor, Optional[int]) -> int
+    pass
+
+
+def maybe_num_nodes(edge_index, num_nodes=None):
+    if num_nodes is not None:
+        return num_nodes
+    elif isinstance(edge_index, Tensor):
+        return int(edge_index.max()) + 1 if edge_index.numel() > 0 else 0
+    else:
+        return max(edge_index.size(0), edge_index.size(1))
 
 
 def maybe_num_nodes_dict(edge_index_dict, num_nodes_dict=None):
