@@ -1,16 +1,18 @@
 from typing import Optional
 
-import torch
 from torch import Tensor
-from torch_scatter import scatter, segment_csr, gather_csr
+from torch_scatter import gather_csr, scatter, segment_csr
 
 from .num_nodes import maybe_num_nodes
 
 
-@torch.jit.script
-def softmax(src: Tensor, index: Optional[Tensor] = None,
-            ptr: Optional[Tensor] = None, num_nodes: Optional[int] = None,
-            dim: int = 0) -> Tensor:
+def softmax(
+    src: Tensor,
+    index: Optional[Tensor] = None,
+    ptr: Optional[Tensor] = None,
+    num_nodes: Optional[int] = None,
+    dim: int = 0,
+) -> Tensor:
     r"""Computes a sparsely evaluated softmax.
     Given a value tensor :attr:`src`, this function first groups the values
     along the first dimension based on the indices specified in :attr:`index`,
@@ -28,6 +30,25 @@ def softmax(src: Tensor, index: Optional[Tensor] = None,
             (default: :obj:`0`)
 
     :rtype: :class:`Tensor`
+
+    Examples:
+
+        >>> src = torch.tensor([1., 1., 1., 1.])
+        >>> index = torch.tensor([0, 0, 1, 2])
+        >>> ptr = torch.tensor([0, 2, 3, 4])
+        >>> softmax(src, index)
+        tensor([0.5000, 0.5000, 1.0000, 1.0000])
+
+        >>> softmax(src, None, ptr)
+        tensor([0.5000, 0.5000, 1.0000, 1.0000])
+
+        >>> src = torch.randn(4, 4)
+        >>> ptr = torch.tensor([0, 4])
+        >>> softmax(src, index, dim=-1)
+        tensor([[0.7404, 0.2596, 1.0000, 1.0000],
+                [0.1702, 0.8298, 1.0000, 1.0000],
+                [0.7607, 0.2393, 1.0000, 1.0000],
+                [0.8062, 0.1938, 1.0000, 1.0000]])
     """
     if ptr is not None:
         dim = dim + src.dim() if dim < 0 else dim
